"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtCore import *
import enum


class QSettings(QObject):
    """
    https://doc.qt.io/qt-6/qsettings.html

    **Detailed Description**

    Users normally expect an application to remember its settings (window sizes
    and positions, options, etc.) across sessions. This information is often
    stored in the system registry on Windows, and in property list files on
    macOS and iOS. On Unix systems, in the absence of a standard, many
    applications (including the KDE applications) use INI text files.

    QSettings is an abstraction around these technologies, enabling you to save
    and restore application settings in a portable manner. It also supports
    **custom storage formats** .

    QSettings's API is based on **QVariant** , allowing you to save most value-
    based types, such as **QString** , **QRect** , and **QImage** , with the
    minimum of effort.

    If all you need is a non-persistent memory-based structure, consider using
    **QMap** <**QString** , **QVariant** > instead.

    **Basic Usage**

    When creating a QSettings object, you must pass the name of your company or
    organization as well as the name of your application. For example, if your
    product is called Star Runner and your company is called MySoft, you would
    construct the QSettings object as follows:

    **QSettings**  settings("MySoft", "Star Runner");

    QSettings objects can be created either on the stack or on the heap (i.e.
    using `new`). Constructing and destroying a QSettings object is very fast.

    If you use QSettings from many places in your application, you might want to
    specify the organization name and the application name using
    **QCoreApplication::setOrganizationName** () and
    **QCoreApplication::setApplicationName** (), and then use the default
    QSettings constructor:

    **QCoreApplication** ::setOrganizationName("MySoft");
    **QCoreApplication** ::setOrganizationDomain("mysoft.com");
    **QCoreApplication** ::setApplicationName("Star Runner");
            ...
    **QSettings**  settings;

    (Here, we also specify the organization's Internet domain. When the Internet
    domain is set, it is used on macOS and iOS instead of the organization name,
    since macOS and iOS applications conventionally use Internet domains to
    identify themselves. If no domain is set, a fake domain is derived from the
    organization name. See the **Platform-Specific Notes**  below for details.)

    QSettings stores settings. Each setting consists of a **QString**  that
    specifies the setting's name (the **key** ) and a **QVariant**  that stores
    the data associated with the key. To write a setting, use **setValue** ().
    For example:

    settings.setValue("editor/wrapMargin", 68);

    If there already exists a setting with the same key, the existing value is
    overwritten by the new value. For efficiency, the changes may not be saved
    to permanent storage immediately. (You can always call **sync** () to commit
    your changes.)

    You can get a setting's value back using **value** ():

    int margin = settings.value("editor/wrapMargin").toInt();

    If there is no setting with the specified name, QSettings returns a null
    **QVariant**  (which can be converted to the integer 0). You can specify
    another default value by passing a second argument to **value** ():

    int margin = settings.value("editor/wrapMargin", 80).toInt();

    To test whether a given key exists, call **contains** (). To remove the
    setting associated with a key, call **remove** (). To obtain the list of all
    keys, call **allKeys** (). To remove all keys, call **clear** ().

    **QVariant and GUI Types**

    Because **QVariant**  is part of the Qt Core module, it cannot provide
    conversion functions to data types such as **QColor** , **QImage** , and
    **QPixmap** , which are part of Qt GUI. In other words, there is no
    `toColor()`, `toImage()`, or `toPixmap()` functions in **QVariant** .

    Instead, you can use the **QVariant::value** () template function. For
    example:

    **QSettings**  settings("MySoft", "Star Runner");
        **QColor**  color =
    settings.value("DataPump/bgcolor").value<**QColor** >();

    The inverse conversion (e.g., from **QColor**  to **QVariant** ) is
    automatic for all data types supported by **QVariant** , including GUI-
    related types:

    **QSettings**  settings("MySoft", "Star Runner");
        **QColor**  color =
    palette().background().color();
        settings.setValue("DataPump/bgcolor",
    color);

    Custom types registered using **qRegisterMetaType** () that have operators
    for streaming to and from a **QDataStream**  can be stored using QSettings.

    **Section and Key Syntax**

    Setting keys can contain any Unicode characters. The Windows registry and
    INI files use case-insensitive keys, whereas the CFPreferences API on macOS
    and iOS uses case-sensitive keys. To avoid portability problems, follow
    these simple rules:

    1. Always refer to the same key using the same case. For example, if you
    refer to a key as "text fonts" in one place in your code, don't refer to it
    as "Text Fonts" somewhere else.
      2. Avoid key names that are identical
    except for the case. For example, if you have a key called "MainWindow",
    don't try to save another key as "mainwindow".
      3. Do not use slashes ('/'
    and '\\') in section or key names; the backslash character is used to
    separate sub keys (see below). On windows '\\' are converted by QSettings to
    '/', which makes them identical.

    You can form hierarchical keys using the '/' character as a separator,
    similar to Unix file paths. For example:

    settings.setValue("mainwindow/size", win->size());
    settings.setValue("mainwindow/fullScreen", win->isFullScreen());
    settings.setValue("outputpanel/visible", panel->isVisible());

    If you want to save or restore many settings with the same prefix, you can
    specify the prefix using **beginGroup** () and call **endGroup** () at the
    end. Here's the same example again, but this time using the group mechanism:

    settings.beginGroup("mainwindow");
            settings.setValue("size",
    win->size());
            settings.setValue("fullScreen", win->isFullScreen());
    settings.endGroup();

            settings.beginGroup("outputpanel");
    settings.setValue("visible", panel->isVisible());
    settings.endGroup();

    If a group is set using **beginGroup** (), the behavior of most functions
    changes consequently. Groups can be set recursively.

    In addition to groups, QSettings also supports an "array" concept. See
    **beginReadArray** () and **beginWriteArray** () for details.

    **Fallback Mechanism**

    Let's assume that you have created a QSettings object with the organization
    name MySoft and the application name Star Runner. When you look up a value,
    up to four locations are searched in that order:

    1. a user-specific location for the Star Runner application
      2. a user-
    specific location for all applications by MySoft
      3. a system-wide location
    for the Star Runner application
      4. a system-wide location for all
    applications by MySoft

    (See **Platform-Specific Notes**  below for information on what these
    locations are on the different platforms supported by Qt.)

    If a key cannot be found in the first location, the search goes on in the
    second location, and so on. This enables you to store system-wide or
    organization-wide settings and to override them on a per-user or per-
    application basis. To turn off this mechanism, call **setFallbacksEnabled**
    (false).

    Although keys from all four locations are available for reading, only the
    first file (the user-specific location for the application at hand) is
    accessible for writing. To write to any of the other files, omit the
    application name and/or specify **QSettings::SystemScope**  (as opposed to
    **QSettings::UserScope** , the default).

    Let's see with an example:

    **QSettings**  obj1("MySoft", "Star Runner");
            **QSettings**
    obj2("MySoft");
            **QSettings**  obj3(**QSettings** ::SystemScope,
    "MySoft", "Star Runner");
            **QSettings**  obj4(**QSettings**
    ::SystemScope, "MySoft");

    The table below summarizes which QSettings objects access which location. "
    **X** " means that the location is the main location associated to the
    QSettings object and is used both for reading and for writing; "o" means
    that the location is used as a fallback when reading.

    Locations`obj1``obj2``obj3``obj4`
    1\\. User, Application **X**
    2\\. User,
    Organizationo **X**
    3\\. System, Applicationo **X**
    4\\. System,
    Organizationooo **X**

    The beauty of this mechanism is that it works on all platforms supported by
    Qt and that it still gives you a lot of flexibility, without requiring you
    to specify any file names or registry paths.

    If you want to use INI files on all platforms instead of the native API, you
    can pass **QSettings::IniFormat**  as the first argument to the QSettings
    constructor, followed by the scope, the organization name, and the
    application name:

    **QSettings**  settings(**QSettings** ::IniFormat, **QSettings**
    ::UserScope,
                               "MySoft", "Star Runner");

    Note that type information is not preserved when reading settings from INI
    files; all values will be returned as **QString** .

    The **Settings Editor**  example lets you experiment with different settings
    location and with fallbacks turned on or off.

    **Restoring the State of a GUI Application**

    QSettings is often used to store the state of a GUI application. The
    following example illustrates how to use QSettings to save and restore the
    geometry of an application's main window.

    void MainWindow::writeSettings()
        {
            **QSettings**
    settings("Moose Soft", "Clipper");
    settings.beginGroup("MainWindow");
            settings.setValue("geometry",
    saveGeometry());
            settings.endGroup();
        }

        void
    MainWindow::readSettings()
        {
            **QSettings**  settings("Moose
    Soft", "Clipper");

            settings.beginGroup("MainWindow");
    const auto geometry = settings.value("geometry", **QByteArray**
    ()).toByteArray();
            if (geometry.isEmpty())
    setGeometry(200, 200, 400, 400);
            else
    restoreGeometry(geometry)
            settings.endGroup();
        }

    See **Window Geometry**  for a discussion on why it is better to call
    **QWidget::resize** () and **QWidget::move** () rather than
    **QWidget::setGeometry** () to restore a window's geometry.

    The `readSettings()` and `writeSettings()` functions must be called from the
    main window's constructor and close event handler as follows:

    MainWindow::MainWindow()
        {
            ...
            readSettings();
        }
    void MainWindow::closeEvent(**QCloseEvent**  *event)
        {
            if
    (userReallyWantsToQuit()) {
                writeSettings();
    event->accept();
            } else {
                event->ignore();
            }
    }

    See the **Application**  example for a self-contained example that uses
    QSettings.

    **Accessing Settings from Multiple Threads or Processes Simultaneously**

    QSettings is **reentrant** . This means that you can use distinct QSettings
    object in different threads simultaneously. This guarantee stands even when
    the QSettings objects refer to the same files on disk (or to the same
    entries in the system registry). If a setting is modified through one
    QSettings object, the change will immediately be visible in any other
    QSettings objects that operate on the same location and that live in the
    same process.

    QSettings can safely be used from different processes (which can be
    different instances of your application running at the same time or
    different applications altogether) to read and write to the same system
    locations, provided certain conditions are met. For **QSettings::IniFormat**
    , it uses advisory file locking and a smart merging algorithm to ensure data
    integrity. The condition for that to work is that the writeable
    configuration file must be a regular file and must reside in a directory
    that the current user can create new, temporary files in. If that is not the
    case, then one must use **setAtomicSyncRequired** () to turn the safety off.

    Note that **sync** () imports changes made by other processes (in addition
    to writing the changes from this QSettings).

    **Platform-Specific Notes**

    **Locations Where Application Settings Are Stored**

    As mentioned in the **Fallback Mechanism**  section, QSettings stores
    settings for an application in up to four locations, depending on whether
    the settings are user-specific or system-wide and whether the settings are
    application-specific or organization-wide. For simplicity, we're assuming
    the organization is called MySoft and the application is called Star Runner.

    On Unix systems, if the file format is **NativeFormat** , the following
    files are used by default:

    1. `$HOME/.config/MySoft/Star Runner.conf` (Qt for Embedded Linux:
    `$HOME/Settings/MySoft/Star Runner.conf`)
      2. `$HOME/.config/MySoft.conf`
    (Qt for Embedded Linux: `$HOME/Settings/MySoft.conf`)
      3. for each
    directory <dir> in $XDG_CONFIG_DIRS: `<dir>/MySoft/Star Runner.conf`
      4.
    for each directory <dir> in $XDG_CONFIG_DIRS: `<dir>/MySoft.conf`

    **Note:** If XDG_CONFIG_DIRS is unset, the default value of `/etc/xdg` is
    used.

    On macOS and iOS, if the file format is **NativeFormat** , these files are
    used by default:

    1. `$HOME/Library/Preferences/com.MySoft.Star Runner.plist`
      2.
    `$HOME/Library/Preferences/com.MySoft.plist`
      3.
    `/Library/Preferences/com.MySoft.Star Runner.plist`
      4.
    `/Library/Preferences/com.MySoft.plist`

    On Windows, **NativeFormat**  settings are stored in the following registry
    paths:

    1. `HKEY_CURRENT_USER\\Software\\MySoft\\Star Runner`
      2.
    `HKEY_CURRENT_USER\\Software\\MySoft\\OrganizationDefaults`
      3.
    `HKEY_LOCAL_MACHINE\\Software\\MySoft\\Star Runner`
      4.
    `HKEY_LOCAL_MACHINE\\Software\\MySoft\\OrganizationDefaults`

    **Note:** On Windows, for 32-bit programs running in WOW64 mode, settings
    are stored in the following registry path:
    `HKEY_LOCAL_MACHINE\\Software\\WOW6432node`.

    If the file format is **NativeFormat** , this is "Settings/MySoft/Star
    Runner.conf" in the application's home directory.

    If the file format is **IniFormat** , the following files are used on Unix,
    macOS, and iOS:

    1. `$HOME/.config/MySoft/Star Runner.ini` (Qt for Embedded Linux:
    `$HOME/Settings/MySoft/Star Runner.ini`)
      2. `$HOME/.config/MySoft.ini` (Qt
    for Embedded Linux: `$HOME/Settings/MySoft.ini`)
      3. for each directory
    <dir> in $XDG_CONFIG_DIRS: `<dir>/MySoft/Star Runner.ini`
      4. for each
    directory <dir> in $XDG_CONFIG_DIRS: `<dir>/MySoft.ini`

    **Note:** If XDG_CONFIG_DIRS is unset, the default value of `/etc/xdg` is
    used.

    On Windows, the following files are used:

    1. `FOLDERID_RoamingAppData\\MySoft\\Star Runner.ini`
      2.
    `FOLDERID_RoamingAppData\\MySoft.ini`
      3. `FOLDERID_ProgramData\\MySoft\\Star
    Runner.ini`
      4. `FOLDERID_ProgramData\\MySoft.ini`

    The identifiers prefixed by `FOLDERID_` are special item ID lists to be
    passed to the Win32 API function `SHGetKnownFolderPath()` to obtain the
    corresponding path.

    `FOLDERID_RoamingAppData` usually points to `C:\\Users\\ **User Name**
    \\AppData\\Roaming`, also shown by the environment variable `%APPDATA%`.

    `FOLDERID_ProgramData` usually points to `C:\\ProgramData`.

    If the file format is **IniFormat** , this is "Settings/MySoft/Star
    Runner.ini" in the application's home directory.

    The paths for the `.ini` and `.conf` files can be changed using **setPath**
    (). On Unix, macOS, and iOS the user can override them by setting the
    `XDG_CONFIG_HOME` environment variable; see **setPath** () for details.

    **Accessing INI and .plist Files Directly**

    Sometimes you do want to access settings stored in a specific file or
    registry path. On all platforms, if you want to read an INI file directly,
    you can use the QSettings constructor that takes a file name as first
    argument and pass **QSettings::IniFormat**  as second argument. For example:

    **QSettings**  settings("/home/petra/misc/myapp.ini",
    **QSettings** ::IniFormat);

    You can then use the QSettings object to read and write settings in the
    file.

    On macOS and iOS, you can access property list `.plist` files by passing
    **QSettings::NativeFormat**  as second argument. For example:

    **QSettings**  settings("/Users/petra/misc/myapp.plist",
    **QSettings** ::NativeFormat);

    **Accessing the Windows Registry Directly**

    On Windows, QSettings lets you access settings that have been written with
    QSettings (or settings in a supported format, e.g., string data) in the
    system registry. This is done by constructing a QSettings object with a path
    in the registry and **QSettings::NativeFormat** .

    For example:

    **QSettings**  settings("HKEY_CURRENT_USER\\\\Software\\\\Microsoft\\\\Office",
    **QSettings** ::NativeFormat);

    All the registry entries that appear under the specified path can be read or
    written through the QSettings object as usual (using forward slashes instead
    of backslashes). For example:

    settings.setValue("11.0/Outlook/Security/DontTrustInstalledFiles", 0);

    Note that the backslash character is, as mentioned, used by QSettings to
    separate subkeys. As a result, you cannot read or write windows registry
    entries that contain slashes or backslashes; you should use a native windows
    API if you need to do so.

    **Accessing Common Registry Settings on Windows**

    On Windows, it is possible for a key to have both a value and subkeys. Its
    default value is accessed by using "Default" or "." in place of a subkey:

    settings.setValue("HKEY_CURRENT_USER\\\\MySoft\\\\Star Runner\\\\Galaxy",
    "Milkyway");
        settings.setValue("HKEY_CURRENT_USER\\\\MySoft\\\\Star
    Runner\\\\Galaxy\\\\Sun", "OurStar");
    settings.value("HKEY_CURRENT_USER\\\\MySoft\\\\Star Runner\\\\Galaxy\\\\Default");
    // returns "Milkyway"

    On other platforms than Windows, "Default" and "." would be treated as
    regular subkeys.

    **Platform Limitations**

    While QSettings attempts to smooth over the differences between the
    different supported platforms, there are still a few differences that you
    should be aware of when porting your application:

    * The Windows system registry has the following limitations: A subkey may
    not exceed 255 characters, an entry's value may not exceed 16,383
    characters, and all the values of a key may not exceed 65,535 characters.
    One way to work around these limitations is to store the settings using the
    **IniFormat**  instead of the **NativeFormat** .
      * On Windows, when the
    Windows system registry is used, QSettings does not preserve the original
    type of the value. Therefore, the type of the value might change when a new
    value is set. For example, a value with type `REG_EXPAND_SZ` will change to
    `REG_SZ`.
      * On macOS and iOS, **allKeys** () will return some extra keys
    for global settings that apply to all applications. These keys can be read
    using **value** () but cannot be changed, only shadowed. Calling
    **setFallbacksEnabled** (false) will hide these global settings.
      * On
    macOS and iOS, the CFPreferences API used by QSettings expects Internet
    domain names rather than organization names. To provide a uniform API,
    QSettings derives a fake domain name from the organization name (unless the
    organization name already is a domain name, e.g. OpenOffice.org). The
    algorithm appends ".com" to the company name and replaces spaces and other
    illegal characters with hyphens. If you want to specify a different domain
    name, call **QCoreApplication::setOrganizationDomain** (),
    **QCoreApplication::setOrganizationName** (), and
    **QCoreApplication::setApplicationName** () in your `main()` function and
    then use the default QSettings constructor. Another solution is to use
    preprocessor directives, for example:

            #ifdef Q_OS_MAC
    **QSettings**  settings("grenoullelogique.fr", "Squash");
        #else
    **QSettings**  settings("Grenoulle Logique", "Squash");
        #endif

      * On
    macOS, permissions to access settings not belonging to the current user
    (i.e. **SystemScope** ) have changed with 10.7 (Lion). Prior to that
    version, users having admin rights could access these. For 10.7 and 10.8
    (Mountain Lion), only root can. However, 10.9 (Mavericks) changes that rule
    again but only for the native format (plist files).

    **See also** **QVariant** , **QSessionManager** , **Settings Editor
    Example** , and **Qt Widgets - Application Example** .
    """

    class Scope(enum.Enum):
        UserScope: QSettings = ...
        SystemScope: QSettings = ...

    class Format(enum.Enum):
        NativeFormat: QSettings = ...
        IniFormat: QSettings = ...
        InvalidFormat: QSettings = ...

    class Status(enum.Enum):
        NoError: QSettings = ...
        AccessError: QSettings = ...
        FormatError: QSettings = ...

    @typing.overload
    def __init__(
        self,
        organization: str,
        application: str = ...,
        parent: typing.Optional[QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#QSettings

        **QSettings::QSettings(const QString & organization , const QString &
        application = QString(), QObject * parent = nullptr)**

        Constructs a QSettings object for accessing settings of the application
        called **application** from the organization called **organization** ,
        and with parent **parent**.

        Example:

        QSettings settings("Moose Tech", "Facturo-Pro");

        The scope is set to **QSettings::UserScope** , and the format is set to
        **QSettings::NativeFormat**  (i.e. calling **setDefaultFormat** ()
        before calling this constructor has no effect).

        **See also** **setDefaultFormat** () and **Fallback Mechanism** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        scope: "QSettings.Scope",
        organization: str,
        application: str = ...,
        parent: typing.Optional[QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#QSettings-1

        **QSettings::QSettings(QSettings::Scope scope , const QString &
        organization , const QString & application = QString(), QObject * parent
        = nullptr)**

        Constructs a QSettings object for accessing settings of the application
        called **application** from the organization called **organization** ,
        and with parent **parent**.

        If **scope** is **QSettings::UserScope** , the QSettings object searches
        user-specific settings first, before it searches system-wide settings as
        a fallback. If **scope** is **QSettings::SystemScope** , the QSettings
        object ignores user-specific settings and provides access to system-wide
        settings.

        The storage format is set to **QSettings::NativeFormat**  (i.e. calling
        **setDefaultFormat** () before calling this constructor has no effect).

        If no application name is given, the QSettings object will only access
        the organization-wide **locations** .

        **See also** **setDefaultFormat** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        format: "QSettings.Format",
        scope: "QSettings.Scope",
        organization: str,
        application: str = ...,
        parent: typing.Optional[QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#QSettings-2

        **QSettings::QSettings(QSettings::Format format , QSettings::Scope scope
        , const QString & organization , const QString & application =
        QString(), QObject * parent = nullptr)**

        Constructs a QSettings object for accessing settings of the application
        called **application** from the organization called **organization** ,
        and with parent **parent**.

        If **scope** is **QSettings::UserScope** , the QSettings object searches
        user-specific settings first, before it searches system-wide settings as
        a fallback. If **scope** is **QSettings::SystemScope** , the QSettings
        object ignores user-specific settings and provides access to system-wide
        settings.

        If **format** is **QSettings::NativeFormat** , the native API is used
        for storing settings. If **format** is **QSettings::IniFormat** , the
        INI format is used.

        If no application name is given, the QSettings object will only access
        the organization-wide **locations** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        fileName: str,
        format: "QSettings.Format",
        parent: typing.Optional[QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#QSettings-3

        **QSettings::QSettings(const QString & fileName , QSettings::Format
        format , QObject * parent = nullptr)**

        Constructs a QSettings object for accessing the settings stored in the
        file called **fileName** , with parent **parent**. If the file doesn't
        already exist, it is created.

        If **format** is **QSettings::NativeFormat** , the meaning of
        **fileName** depends on the platform. On Unix, **fileName** is the name
        of an INI file. On macOS and iOS, **fileName** is the name of a `.plist`
        file. On Windows, **fileName** is a path in the system registry.

        If **format** is **QSettings::IniFormat** , **fileName** is the name of
        an INI file.

        **Warning:** This function is provided for convenience. It works well
        for accessing INI or `.plist` files generated by Qt, but might fail on
        some syntaxes found in such files originated by other programs. In
        particular, be aware of the following limitations:

        * QSettings provides no way of reading INI "path" entries, i.e., entries
        with unescaped slash characters. (This is because these entries are
        ambiguous and cannot be resolved automatically.)
          * In INI files,
        QSettings uses the `@` character as a metacharacter in some contexts, to
        encode Qt-specific data types (e.g., `@Rect`), and might therefore
        misinterpret it when it occurs in pure INI files.

        **See also** **fileName** ().
        """
        ...

    @typing.overload
    def __init__(
        self, scope: "QSettings.Scope", parent: typing.Optional[QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#QSettings-4

        **QSettings::QSettings(QObject * parent = nullptr)**

        Constructs a QSettings object for accessing settings of the application
        and organization set previously with a call to
        **QCoreApplication::setOrganizationName** (),
        **QCoreApplication::setOrganizationDomain** (), and
        **QCoreApplication::setApplicationName** ().

        The scope is **QSettings::UserScope**  and the format is
        **defaultFormat** () (**QSettings::NativeFormat**  by default). Use
        **setDefaultFormat** () before calling this constructor to change the
        default format used by this constructor.

        The code

        **QSettings**  settings("Moose Soft", "Facturo-Pro");

        is equivalent to

        **QCoreApplication** ::setOrganizationName("Moose Soft");
        **QCoreApplication** ::setApplicationName("Facturo-Pro");
        **QSettings**  settings;

        If **QCoreApplication::setOrganizationName** () and
        **QCoreApplication::setApplicationName** () has not been previously
        called, the QSettings object will not be able to read or write any
        settings, and **status** () will return **AccessError** .

        You should supply both the domain (used by default on macOS and iOS) and
        the name (used by default elsewhere), although the code will cope if you
        supply only one, which will then be used (on all platforms), at odds
        with the usual naming of the file on platforms for which it isn't the
        default.

        **See also** **QCoreApplication::setOrganizationName** (),
        **QCoreApplication::setOrganizationDomain** (),
        **QCoreApplication::setApplicationName** (), and **setDefaultFormat**
        ().
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#QSettings-5

        **[since 5.13] QSettings::QSettings(QSettings::Scope scope , QObject *
        parent = nullptr)**

        Constructs a QSettings object in the same way as QSettings(**QObject**
        *parent) but with the given **scope**.

        This function was introduced in Qt 5.13.

        **See also** **QSettings** (QObject *parent).
        """
        ...

    def event(self, event: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsettings.html#event

        **[override virtual protected] bool QSettings::event(QEvent * event )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def setAtomicSyncRequired(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#setAtomicSyncRequired

        **[since 5.10] void QSettings::setAtomicSyncRequired(bool enable )**

        Configures whether **QSettings**  is required to perform atomic saving
        and reloading (synchronization) of the settings. If the **enable**
        argument is `true` (the default), **sync** () will only perform
        synchronization operations that are atomic. If this is not possible,
        **sync** () will fail and **status** () will be an error condition.

        Setting this property to `false` will allow **QSettings**  to write
        directly to the configuration file and ignore any errors trying to lock
        it against other processes trying to write at the same time. Because of
        the potential for corruption, this option should be used with care, but
        is required in certain conditions, like a **QSettings::IniFormat**
        configuration file that exists in an otherwise non-writeable directory
        or NTFS Alternate Data Streams.

        See **QSaveFile**  for more information on the feature.

        This function was introduced in Qt 5.10.

        **See also** **isAtomicSyncRequired** () and **QSaveFile** .
        """
        ...

    def isAtomicSyncRequired(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsettings.html#isAtomicSyncRequired

        **[since 5.10] bool QSettings::isAtomicSyncRequired() const**

        Returns `true` if **QSettings**  is only allowed to perform atomic
        saving and reloading (synchronization) of the settings. Returns `false`
        if it is allowed to save the settings contents directly to the
        configuration file.

        The default is `true`.

        This function was introduced in Qt 5.10.

        **See also** **setAtomicSyncRequired** () and **QSaveFile** .
        """
        ...

    @staticmethod
    def defaultFormat() -> "QSettings.Format":
        """
        https://doc.qt.io/qt-6/qsettings.html#defaultFormat

        **[static] QSettings::Format QSettings::defaultFormat()**

        Returns default file format used for storing settings for the
        **QSettings** (**QObject**  *) constructor. If no default format is set,
        **QSettings::NativeFormat**  is used.

        **See also** **setDefaultFormat** () and **format** ().
        """
        ...

    @staticmethod
    def setDefaultFormat(format: "QSettings.Format") -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#setDefaultFormat

        **[static] void QSettings::setDefaultFormat(QSettings::Format format )**

        Sets the default file format to the given **format** , which is used for
        storing settings for the **QSettings** (**QObject**  *) constructor.

        If no default format is set, **QSettings::NativeFormat**  is used. See
        the documentation for the **QSettings**  constructor you are using to
        see if that constructor will ignore this function.

        **See also** **defaultFormat** () and **format** ().
        """
        ...

    def applicationName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsettings.html#applicationName

        **QString QSettings::applicationName() const**

        Returns the application name used for storing the settings.

        **See also** **QCoreApplication::applicationName** (), **format** (),
        **scope** (), and **organizationName** ().
        """
        ...

    def organizationName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsettings.html#organizationName

        **QString QSettings::organizationName() const**

        Returns the organization name used for storing the settings.

        **See also** **QCoreApplication::organizationName** (), **format** (),
        **scope** (), and **applicationName** ().
        """
        ...

    def scope(self) -> "QSettings.Scope":
        """
        https://doc.qt.io/qt-6/qsettings.html#scope

        **QSettings::Scope QSettings::scope() const**

        Returns the scope used for storing the settings.

        **See also** **format** (), **organizationName** (), and
        **applicationName** ().
        """
        ...

    def format(self) -> "QSettings.Format":
        """
        https://doc.qt.io/qt-6/qsettings.html#format

        **QSettings::Format QSettings::format() const**

        Returns the format used for storing the settings.

        **See also** **defaultFormat** (), **fileName** (), **scope** (),
        **organizationName** (), and **applicationName** ().
        """
        ...

    @staticmethod
    def setPath(
        format: "QSettings.Format", scope: "QSettings.Scope", path: str
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#setPath

        **[static] void QSettings::setPath(QSettings::Format format ,
        QSettings::Scope scope , const QString & path )**

        Sets the path used for storing settings for the given **format** and
        **scope** , to **path**. The **format** can be a custom format.

        The table below summarizes the default values:

        PlatformFormatScopePath
        Windows**IniFormat** **UserScope**
        `FOLDERID_RoamingAppData`
        **SystemScope** `FOLDERID_ProgramData`
        Unix**NativeFormat** , **IniFormat** **UserScope** `$HOME/.config`
        **SystemScope** `/etc/xdg`
        Qt for Embedded Linux**NativeFormat** ,
        **IniFormat** **UserScope** `$HOME/Settings`
        **SystemScope**
        `/etc/xdg`
        macOS and iOS**IniFormat** **UserScope** `$HOME/.config`
        **SystemScope** `/etc/xdg`

        The default **UserScope**  paths on Unix, macOS, and iOS
        (`$HOME/.config` or $HOME/Settings) can be overridden by the user by
        setting the `XDG_CONFIG_HOME` environment variable. The default
        **SystemScope**  paths on Unix, macOS, and iOS (`/etc/xdg`) can be
        overridden when building the Qt library using the `configure` script's
        `-sysconfdir` flag (see **QLibraryInfo**  for details).

        Setting the **NativeFormat**  paths on Windows, macOS, and iOS has no
        effect.

        **Warning:** This function doesn't affect existing **QSettings**
        objects.

        **See also** **registerFormat** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsettings.html#fileName

        **QString QSettings::fileName() const**

        Returns the path where settings written using this **QSettings**  object
        are stored.

        On Windows, if the format is **QSettings::NativeFormat** , the return
        value is a system registry path, not a file path.

        **See also** **isWritable** () and **format** ().
        """
        ...

    def fallbacksEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsettings.html#fallbacksEnabled

        **bool QSettings::fallbacksEnabled() const**

        Returns `true` if fallbacks are enabled; returns `false` otherwise.

        By default, fallbacks are enabled.

        **See also** **setFallbacksEnabled** ().
        """
        ...

    def setFallbacksEnabled(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#setFallbacksEnabled

        **void QSettings::setFallbacksEnabled(bool b )**

        Sets whether fallbacks are enabled to **b**.

        By default, fallbacks are enabled.

        **See also** **fallbacksEnabled** ().
        """
        ...

    def contains(self, key: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsettings.html#contains

        **bool QSettings::contains(const QString & key ) const**

        Returns `true` if there exists a setting called **key** ; returns false
        otherwise.

        If a group is set using **beginGroup** (), **key** is taken to be
        relative to that group.

        Note that the Windows registry and INI files use case-insensitive keys,
        whereas the CFPreferences API on macOS and iOS uses case-sensitive keys.
        To avoid portability problems, see the **Section and Key Syntax**
        rules.

        **See also** **value** () and **setValue** ().
        """
        ...

    def remove(self, key: str) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#remove

        **void QSettings::remove(const QString & key )**

        Removes the setting **key** and any sub-settings of **key**.

        Example:

        **QSettings**  settings;
            settings.setValue("ape");
        settings.setValue("monkey", 1);
            settings.setValue("monkey/sea", 2);
        settings.setValue("monkey/doe", 4);

            settings.remove("monkey");
        **QStringList**  keys = settings.allKeys();
            // keys: ["ape"]

        Be aware that if one of the fallback locations contains a setting with
        the same key, that setting will be visible after calling remove().

        If **key** is an empty string, all keys in the current **group** () are
        removed. For example:

        **QSettings**  settings;
            settings.setValue("ape");
        settings.setValue("monkey", 1);
            settings.setValue("monkey/sea", 2);
        settings.setValue("monkey/doe", 4);
        settings.beginGroup("monkey");
            settings.remove("");
        settings.endGroup();

            **QStringList**  keys =
        settings.allKeys();
            // keys: ["ape"]

        Note that the Windows registry and INI files use case-insensitive keys,
        whereas the CFPreferences API on macOS and iOS uses case-sensitive keys.
        To avoid portability problems, see the **Section and Key Syntax**
        rules.

        **See also** **setValue** (), **value** (), and **contains** ().
        """
        ...

    def value(
        self, key: str, defaultValue: typing.Any = ..., type: type = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsettings.html#value

        **QVariant QSettings::value(const QString & key , const QVariant &
        defaultValue = QVariant()) const**

        Returns the value for setting **key**. If the setting doesn't exist,
        returns **defaultValue**.

        If no default value is specified, a default **QVariant**  is returned.

        Note that the Windows registry and INI files use case-insensitive keys,
        whereas the CFPreferences API on macOS and iOS uses case-sensitive keys.
        To avoid portability problems, see the **Section and Key Syntax**
        rules.

        Example:

        **QSettings**  settings;
            settings.setValue("animal/snake", 58);
        settings.value("animal/snake", 1024).toInt();   // returns 58
        settings.value("animal/zebra", 1024).toInt();   // returns 1024
        settings.value("animal/zebra").toInt();         // returns 0

        **See also** **setValue** (), **contains** (), and **remove** ().
        """
        ...

    def setValue(self, key: str, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#setValue

        **void QSettings::setValue(const QString & key , const QVariant & value
        )**

        Sets the value of setting **key** to **value**. If the **key** already
        exists, the previous value is overwritten.

        Note that the Windows registry and INI files use case-insensitive keys,
        whereas the CFPreferences API on macOS and iOS uses case-sensitive keys.
        To avoid portability problems, see the **Section and Key Syntax**
        rules.

        Example:

        **QSettings**  settings;
            settings.setValue("interval", 30);
        settings.value("interval").toInt();     // returns 30
        settings.setValue("interval", 6.55);
        settings.value("interval").toDouble();  // returns 6.55

        **See also** **value** (), **remove** (), and **contains** ().
        """
        ...

    def isWritable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsettings.html#isWritable

        **bool QSettings::isWritable() const**

        Returns `true` if settings can be written using this **QSettings**
        object; returns `false` otherwise.

        One reason why isWritable() might return false is if **QSettings**
        operates on a read-only file.

        **Warning:** This function is not perfectly reliable, because the file
        permissions can change at any time.

        **See also** **fileName** (), **status** (), and **sync** ().
        """
        ...

    def childGroups(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsettings.html#childGroups

        **QStringList QSettings::childGroups() const**

        Returns a list of all key top-level groups that contain keys that can be
        read using the **QSettings**  object.

        Example:

        **QSettings**  settings;
            settings.setValue("fridge/color",
        **QColor** (Qt::white));
            settings.setValue("fridge/size", **QSize**
        (32, 96));
            settings.setValue("sofa", true);
        settings.setValue("tv", false);

            **QStringList**  groups =
        settings.childGroups();
            // groups: ["fridge"]

        If a group is set using **beginGroup** (), the first-level keys in that
        group are returned, without the group prefix.

        settings.beginGroup("fridge");
            groups = settings.childGroups();
        // groups: []

        You can navigate through the entire setting hierarchy using
        **childKeys** () and childGroups() recursively.

        **See also** **childKeys** () and **allKeys** ().
        """
        ...

    def childKeys(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsettings.html#childKeys

        **QStringList QSettings::childKeys() const**

        Returns a list of all top-level keys that can be read using the
        **QSettings**  object.

        Example:

        **QSettings**  settings;
            settings.setValue("fridge/color",
        **QColor** (Qt::white));
            settings.setValue("fridge/size", **QSize**
        (32, 96));
            settings.setValue("sofa", true);
        settings.setValue("tv", false);

            **QStringList**  keys =
        settings.childKeys();
            // keys: ["sofa", "tv"]

        If a group is set using **beginGroup** (), the top-level keys in that
        group are returned, without the group prefix:

        settings.beginGroup("fridge");
            keys = settings.childKeys();
            //
        keys: ["color", "size"]

        You can navigate through the entire setting hierarchy using childKeys()
        and **childGroups** () recursively.

        **See also** **childGroups** () and **allKeys** ().
        """
        ...

    def allKeys(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsettings.html#allKeys

        **QStringList QSettings::allKeys() const**

        Returns a list of all keys, including subkeys, that can be read using
        the **QSettings**  object.

        Example:

        **QSettings**  settings;
            settings.setValue("fridge/color",
        **QColor** (Qt::white));
            settings.setValue("fridge/size", **QSize**
        (32, 96));
            settings.setValue("sofa", true);
        settings.setValue("tv", false);

            **QStringList**  keys =
        settings.allKeys();
            // keys: ["fridge/color", "fridge/size", "sofa",
        "tv"]

        If a group is set using **beginGroup** (), only the keys in the group
        are returned, without the group prefix:

        settings.beginGroup("fridge");
            keys = settings.allKeys();
            //
        keys: ["color", "size"]

        **See also** **childGroups** () and **childKeys** ().
        """
        ...

    def setArrayIndex(self, i: int) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#setArrayIndex

        **void QSettings::setArrayIndex(int i )**

        Sets the current array index to **i**. Calls to functions such as
        **setValue** (), **value** (), **remove** (), and **contains** () will
        operate on the array entry at that index.

        You must call **beginReadArray** () or **beginWriteArray** () before you
        can call this function.
        """
        ...

    def endArray(self) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#endArray

        **void QSettings::endArray()**

        Closes the array that was started using **beginReadArray** () or
        **beginWriteArray** ().

        **See also** **beginReadArray** () and **beginWriteArray** ().
        """
        ...

    def beginWriteArray(self, prefix: str, size: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#beginWriteArray

        **void QSettings::beginWriteArray(const QString & prefix , int size =
        -1)**

        Adds **prefix** to the current group and starts writing an array of size
        **size**. If **size** is -1 (the default), it is automatically
        determined based on the indexes of the entries written.

        If you have many occurrences of a certain set of keys, you can use
        arrays to make your life easier. For example, let's suppose that you
        want to save a variable-length list of user names and passwords. You
        could then write:

        struct Login {
                **QString**  userName;
                **QString**
        password;
            };
            **QList** <Login> logins;
            ...
        **QSettings**  settings;
            settings.beginWriteArray("logins");
            for
        (int i = 0; i < logins.size(); ++i) {
                settings.setArrayIndex(i);
        settings.setValue("userName", list.at(i).userName);
        settings.setValue("password", list.at(i).password);
            }
        settings.endArray();

        The generated keys will have the form

        * `logins/size`
          * `logins/1/userName`
          * `logins/1/password`
          *
        `logins/2/userName`
          * `logins/2/password`
          * `logins/3/userName`
          *
        `logins/3/password`
          * ...

        To read back an array, use **beginReadArray** ().

        **See also** **beginReadArray** (), **endArray** (), and
        **setArrayIndex** ().
        """
        ...

    def beginReadArray(self, prefix: str) -> int:
        """
        https://doc.qt.io/qt-6/qsettings.html#beginReadArray

        **int QSettings::beginReadArray(const QString & prefix )**

        Adds **prefix** to the current group and starts reading from an array.
        Returns the size of the array.

        Example:

        struct Login {
                **QString**  userName;
                **QString**
        password;
            };
            **QList** <Login> logins;
            ...
        **QSettings**  settings;
            int size =
        settings.beginReadArray("logins");
            for (int i = 0; i < size; ++i) {
        settings.setArrayIndex(i);
                Login login;
                login.userName =
        settings.value("userName").toString();
                login.password =
        settings.value("password").toString();
                logins.append(login);
        }
            settings.endArray();

        Use **beginWriteArray** () to write the array in the first place.

        **See also** **beginWriteArray** (), **endArray** (), and
        **setArrayIndex** ().
        """
        ...

    def group(self) -> str:
        """
        https://doc.qt.io/qt-6/qsettings.html#group

        **QString QSettings::group() const**

        Returns the current group.

        **See also** **beginGroup** () and **endGroup** ().
        """
        ...

    def endGroup(self) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#endGroup

        **void QSettings::endGroup()**

        Resets the group to what it was before the corresponding **beginGroup**
        () call.

        Example:

        settings.beginGroup("alpha");
            // settings.group() == "alpha"
        settings.beginGroup("beta");
            // settings.group() == "alpha/beta"
        settings.endGroup();
            // settings.group() == "alpha"
        settings.endGroup();
            // settings.group() == ""

        **See also** **beginGroup** () and **group** ().
        """
        ...

    def beginGroup(self, prefix: str) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#beginGroup

        **void QSettings::beginGroup(const QString & prefix )**

        Appends **prefix** to the current group.

        The current group is automatically prepended to all keys specified to
        **QSettings** . In addition, query functions such as **childGroups** (),
        **childKeys** (), and **allKeys** () are based on the group. By default,
        no group is set.

        Groups are useful to avoid typing in the same setting paths over and
        over. For example:

        settings.beginGroup("mainwindow");
            settings.setValue("size",
        win->size());
            settings.setValue("fullScreen", win->isFullScreen());
        settings.endGroup();

            settings.beginGroup("outputpanel");
        settings.setValue("visible", panel->isVisible());
        settings.endGroup();

        This will set the value of three settings:

        * `mainwindow/size`
          * `mainwindow/fullScreen`
          *
        `outputpanel/visible`

        Call **endGroup** () to reset the current group to what it was before
        the corresponding beginGroup() call. Groups can be nested.

        **See also** **endGroup** () and **group** ().
        """
        ...

    def status(self) -> "QSettings.Status":
        """
        https://doc.qt.io/qt-6/qsettings.html#status

        **QSettings::Status QSettings::status() const**

        Returns a status code indicating the first error that was met by
        **QSettings** , or **QSettings::NoError**  if no error occurred.

        Be aware that **QSettings**  delays performing some operations. For this
        reason, you might want to call **sync** () to ensure that the data
        stored in **QSettings**  is written to disk before calling status().

        **See also** **sync** ().
        """
        ...

    def sync(self) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#sync

        **void QSettings::sync()**

        Writes any unsaved changes to permanent storage, and reloads any
        settings that have been changed in the meantime by another application.

        This function is called automatically from **QSettings** 's destructor
        and by the event loop at regular intervals, so you normally don't need
        to call it yourself.

        **See also** **status** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsettings.html#clear

        **void QSettings::clear()**

        Removes all entries in the primary location associated to this
        **QSettings**  object.

        Entries in fallback locations are not removed.

        If you only want to remove the entries in the current **group** (), use
        remove("") instead.

        **See also** **remove** () and **setFallbacksEnabled** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore


class QHelpSearchResultWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qhelpsearchresultwidget.html

    **Detailed Description**
    """

    def linkAt(self, point: QtCore.QPoint) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qhelpsearchresultwidget.html#linkAt

        **QUrl QHelpSearchResultWidget::linkAt(const QPoint & point )**

        Returns a reference of the URL that the item at **point** owns, or an
        empty URL if no item exists at that point.
        """
        ...

    @property
    def requestShowLink(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpsearchresultwidget.html#requestShowLink

        **[signal] void QHelpSearchResultWidget::requestShowLink(const QUrl &
        link )**

        This signal is emitted when a item is activated and its associated
        **link** should be shown.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPicture(QPaintDevice):
    """
    https://doc.qt.io/qt-6/qpicture.html

    **Detailed Description**

    A picture serializes painter commands to an IO device in a platform-
    independent format. They are sometimes referred to as meta-files.

    Qt pictures use a proprietary binary format. Unlike native picture (meta-
    file) formats on many window systems, Qt pictures have no limitations
    regarding their contents. Everything that can be painted on a widget or
    pixmap (e.g., fonts, pixmaps, regions, transformed graphics, etc.) can also
    be stored in a picture.

    QPicture is resolution independent, i.e. a QPicture can be displayed on
    different devices (for example svg, pdf, ps, printer and screen) looking the
    same. This is, for instance, needed for WYSIWYG print preview. QPicture runs
    in the default system dpi, and scales the painter to match differences in
    resolution depending on the window system.

    Example of how to record a picture:

    **QPicture**  picture;
        **QPainter**  painter;
    painter.begin(&picture);           // paint in picture
    painter.drawEllipse(10,20, 80,70); // draw an ellipse
        painter.end();
    // painting done
        picture.save("drawing.pic");       // save picture

    Note that the list of painter commands is reset on each call to the
    **QPainter::begin** () function.

    Example of how to replay a picture:

    **QPicture**  picture;
        picture.load("drawing.pic");           // load
    picture
        **QPainter**  painter;
        painter.begin(&myImage);
    // paint in myImage
        painter.drawPicture(0, 0, picture);    // draw the
    picture at (0,0)
        painter.end();                         // painting done

    Pictures can also be drawn using **play** (). Some basic data about a
    picture is available, for example, **size** (), **isNull** () and
    **boundingRect** ().

    **See also** **QMovie** .
    """

    @typing.overload
    def __init__(self, formatVersion: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpicture.html#QPicture

        **QPicture::QPicture(int formatVersion = -1)**

        Constructs an empty picture.

        The **formatVersion** parameter may be used to **create** a QPicture
        that can be read by applications that are compiled with earlier versions
        of Qt.

        Note that the default formatVersion is -1 which signifies the current
        release, i.e. for Qt 4.0 a formatVersion of 7 is the same as the default
        formatVersion of -1.

        Reading pictures generated by earlier versions of Qt is not supported in
        Qt 4.0.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPicture") -> None:
        """
        https://doc.qt.io/qt-6/qpicture.html#QPicture-1

        **QPicture::QPicture(const QPicture & pic )**

        Constructs a copy of **pic**.

        This constructor is fast thanks to **implicit sharing** .
        """
        ...

    def swap(self, other: "QPicture") -> None:
        """
        https://doc.qt.io/qt-6/qpicture.html#swap

        **void QPicture::swap(QPicture & other )**

        Swaps picture **other** with this picture. This operation is very fast
        and never fails.
        """
        ...

    def metric(self, m: QPaintDevice.PaintDeviceMetric) -> int:
        ...

    def paintEngine(self) -> QPaintEngine:
        ...

    def isDetached(self) -> bool:
        ...

    def detach(self) -> None:
        ...

    def setBoundingRect(self, r: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qpicture.html#setBoundingRect

        **void QPicture::setBoundingRect(const QRect & r )**

        Sets the picture's bounding rectangle to **r**. The automatically
        calculated value is overridden.

        **See also** **boundingRect** ().
        """
        ...

    def boundingRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpicture.html#boundingRect

        **QRect QPicture::boundingRect() const**

        Returns the picture's bounding rectangle or an invalid rectangle if the
        picture contains no data.

        **See also** **setBoundingRect** ().
        """
        ...

    @typing.overload
    def save(self, fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qpicture.html#save

        **bool QPicture::save(const QString & fileName )**

        Saves a picture to the file specified by **fileName** and returns true
        if successful; otherwise returns `false`.

        **See also** **load** ().
        """
        ...

    @typing.overload
    def save(self, dev: QtCore.QIODevice) -> bool:
        """
        https://doc.qt.io/qt-6/qpicture.html#save-1

        **bool QPicture::save(QIODevice * dev )**

        This is an overloaded function.

        **dev** is the device to use for saving.
        """
        ...

    @typing.overload
    def load(self, fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qpicture.html#load

        **bool QPicture::load(const QString & fileName )**

        Loads a picture from the file specified by **fileName** and returns true
        if successful; otherwise invalidates the picture and returns `false`.

        **See also** **save** ().
        """
        ...

    @typing.overload
    def load(self, dev: QtCore.QIODevice) -> bool:
        """
        https://doc.qt.io/qt-6/qpicture.html#load-1

        **bool QPicture::load(QIODevice * dev )**

        This is an overloaded function.

        **dev** is the device to use for loading.
        """
        ...

    def play(self, p: QPainter) -> bool:
        """
        https://doc.qt.io/qt-6/qpicture.html#play

        **bool QPicture::play(QPainter * painter )**

        Replays the picture using **painter** , and returns `true` if
        successful; otherwise returns `false`.

        This function does exactly the same as **QPainter::drawPicture** () with
        (x, y) = (0, 0).

        **Note:** The state of the painter isn't preserved by this function.
        """
        ...

    def setData(self, data: bytes) -> None:
        """
        https://doc.qt.io/qt-6/qpicture.html#setData

        **[virtual] void QPicture::setData(const char * data , uint size )**

        Sets the picture data directly from **data** and **size**. This function
        copies the input data.

        **See also** **data** () and **size** ().
        """
        ...

    def data(self) -> bytes:
        """
        https://doc.qt.io/qt-6/qpicture.html#data

        **const char *QPicture::data() const**

        Returns a pointer to the picture data. The pointer is only valid until
        the next non-const function is called on this picture. The returned
        pointer is 0 if the picture contains no data.

        **See also** **setData** (), **size** (), and **isNull** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qpicture.html#size

        **uint QPicture::size() const**

        Returns the size of the picture data.

        **See also** **data** ().
        """
        ...

    def devType(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpicture.html#isNull

        **bool QPicture::isNull() const**

        Returns `true` if the picture contains no data; otherwise returns false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QLowEnergyConnectionParameters(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html

    **Detailed Description**

    The connection parameters influence how often a master and a slave device
    synchronize with each other. In general, a lower connection interval and
    latency means faster communication, but also higher power consumption. How
    these criteria should be weighed against each other is highly dependent on
    the concrete use case.

    Android only indirectly permits the adjustment of this parameter set. The
    platform separates the connection parameters into three categories (hight,
    low & balanced priority). Each category implies a predefined set of values
    for **minimumInterval** (), **maximumInterval** () and **latency** ().
    Additionally, the value ranges of each category can vary from one Android
    device to the next. Qt uses the **minimumInterval** () to determine the
    target category as follows:

    **minimumInterval** ()Android priority
    interval <
    30CONNECTION_PRIORITY_HIGH
    30 <= interval <=
    100CONNECTION_PRIORITY_BALANCED
    interval >
    100CONNECTION_PRIORITY_LOW_POWER

    The **supervisionTimeout** () cannot be changed on Android and is therefore
    ignored.

    **See also** **QLowEnergyController::requestConnectionUpdate**  and
    **QLowEnergyController::connectionUpdated** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#QLowEnergyCon
        nectionParameters

        **QLowEnergyConnectionParameters::QLowEnergyConnectionParameters()**

        Constructs a new object of this class. All values are initialized to
        valid defaults.
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyConnectionParameters") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#QLowEnergyCon
        nectionParameters-1

        **QLowEnergyConnectionParameters::QLowEnergyConnectionParameters(const
        QLowEnergyConnectionParameters & other )**

        Constructs a new object of this class that is a copy of **other**.
        """
        ...

    def swap(self, other: "QLowEnergyConnectionParameters") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#swap

        **void
        QLowEnergyConnectionParameters::swap(QLowEnergyConnectionParameters &
        other )**

        Swaps this object with **other**.
        """
        ...

    def supervisionTimeout(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#supervisionTi
        meout

        **int QLowEnergyConnectionParameters::supervisionTimeout() const**

        Returns the link supervision timeout of the connection in milliseconds.

        **See also** **setSupervisionTimeout** ().
        """
        ...

    def setSupervisionTimeout(self, timeout: int) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#setSupervisio
        nTimeout

        **void QLowEnergyConnectionParameters::setSupervisionTimeout(int timeout
        )**

        Sets the link supervision timeout to **timeout** milliseconds. There are
        several constraints on this value: It must be in the range [100,32000]
        and it must be larger than (1 + **latency** ()) * 2 *
        **maximumInterval** ().

        On Android, this timeout is not adjustable and therefore ignored.

        **See also** **supervisionTimeout** ().
        """
        ...

    def latency(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#latency

        **int QLowEnergyConnectionParameters::latency() const**

        Returns the slave latency of the connection.

        **See also** **setLatency** ().
        """
        ...

    def setLatency(self, latency: int) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#setLatency

        **void QLowEnergyConnectionParameters::setLatency(int latency )**

        Sets the slave latency of the connection (that is, the number of
        connection events that a slave device is allowed to ignore) to
        **latency**. The minimum value is 0, the maximum is 499.

        **See also** **latency** ().
        """
        ...

    def maximumInterval(self) -> float:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#maximumInterv
        al

        **double QLowEnergyConnectionParameters::maximumInterval() const**

        Returns the maximum connection interval in milliseconds. The default is
        4000.

        **Note:** If this object was emitted via
        **QLowEnergyController::connectionUpdated** (), then this value is the
        same as **minimumInterval** () and refers to the actual connection
        interval.

        **See also** **setIntervalRange** ().
        """
        ...

    def minimumInterval(self) -> float:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#minimumInterv
        al

        **double QLowEnergyConnectionParameters::minimumInterval() const**

        Returns the minimum connection interval in milliseconds. The default is
        7.5.

        **Note:** If this object was emitted via
        **QLowEnergyController::connectionUpdated** (), then this value is the
        same as **maximumInterval** () and refers to the actual connection
        interval.

        **See also** **setIntervalRange** ().
        """
        ...

    def setIntervalRange(self, minimum: float, maximum: float) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyconnectionparameters.html#setIntervalRa
        nge

        **void QLowEnergyConnectionParameters::setIntervalRange(double minimum ,
        double maximum )**

        Sets the range in which the connection interval should be. The actual
        value will be decided by the controller. Both **minimum** and
        **maximum** are given in milliseconds. If **maximum** is smaller than
        **minimum** , it will be set to the value of **minimum**. The smallest
        possible connection interval is 7.5 milliseconds, the largest one is
        4000 milliseconds.

        **See also** **minimumInterval** () and **maximumInterval** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextBlockFormat(QTextFormat):
    """
    https://doc.qt.io/qt-6/qtextblockformat.html

    **Detailed Description**

    A document is composed of a list of blocks, represented by **QTextBlock**
    objects. Each block can contain an item of some kind, such as a paragraph of
    text, a table, a list, or an image. Every block has an associated
    QTextBlockFormat that specifies its characteristics.

    To cater for left-to-right and right-to-left languages you can set a block's
    direction with setDirection(). Paragraph alignment is set with
    **setAlignment** (). Margins are controlled by **setTopMargin** (),
    **setBottomMargin** (), **setLeftMargin** (), **setRightMargin** (). Overall
    indentation is set with **setIndent** (), the indentation of the first line
    with **setTextIndent** ().

    Line spacing is set with **setLineHeight** () and retrieved via
    **lineHeight** () and **lineHeightType** (). The types of line spacing
    available are in the **LineHeightTypes**  enum.

    Line breaking can be enabled and disabled with **setNonBreakableLines** ().

    The brush used to paint the paragraph's background is set with
    **setBackground** (), and other aspects of the text's appearance can be
    customized by using the **setProperty** () function with the `OutlinePen`,
    `ForegroundBrush`, and `BackgroundBrush` **QTextFormat::Property**  values.

    If a text block is part of a list, it can also have a list format that is
    accessible with the listFormat() function.

    **See also** **QTextBlock**  and **QTextCharFormat** .
    """

    class MarkerType(enum.Enum):
        NoMarker: QTextBlockFormat = ...
        Unchecked: QTextBlockFormat = ...
        Checked: QTextBlockFormat = ...

    class LineHeightTypes(enum.Enum):
        SingleHeight: QTextBlockFormat = ...
        ProportionalHeight: QTextBlockFormat = ...
        FixedHeight: QTextBlockFormat = ...
        MinimumHeight: QTextBlockFormat = ...
        LineDistanceHeight: QTextBlockFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#QTextBlockFormat

        **QTextBlockFormat::QTextBlockFormat()**

        Constructs a new QTextBlockFormat.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextBlockFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#QTextBlockFormat

        **QTextBlockFormat::QTextBlockFormat()**

        Constructs a new QTextBlockFormat.
        """
        ...

    def marker(self) -> "QTextBlockFormat.MarkerType":
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#marker

        **[since 5.14] QTextBlockFormat::MarkerType QTextBlockFormat::marker()
        const**

        Returns the paragraph's marker if one has been set, or `NoMarker` if
        not.

        This function was introduced in Qt 5.14.

        **See also** **setMarker** ().
        """
        ...

    def setMarker(self, marker: "QTextBlockFormat.MarkerType") -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setMarker

        **[since 5.14] void
        QTextBlockFormat::setMarker(QTextBlockFormat::MarkerType marker )**

        Sets the type of adornment that should be rendered alongside the
        paragraph to **marker**. For example, a list item can be adorned with a
        checkbox, either checked or unchecked, as a replacement for its bullet.
        The default is `NoMarker`.

        This function was introduced in Qt 5.14.

        **See also** **marker** ().
        """
        ...

    def headingLevel(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#headingLevel

        **[since 5.12] int QTextBlockFormat::headingLevel() const**

        Returns the paragraph's heading level if it is a heading, or 0 if not.

        This function was introduced in Qt 5.12.

        **See also** **setHeadingLevel** ().
        """
        ...

    def setHeadingLevel(self, alevel: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setHeadingLevel

        **[since 5.12] void QTextBlockFormat::setHeadingLevel(int level )**

        Sets the paragraph's heading **level** , where 1 is the highest-level
        heading type (usually with the largest possible heading font size), and
        increasing values are progressively deeper into the document (and
        usually with smaller font sizes). For example when reading an HTML H1
        tag, the heading level is set to 1. Setting the heading level does not
        automatically change the font size; however
        **QTextDocumentFragment::fromHtml** () sets both the heading level and
        the font size simultaneously.

        If the paragraph is not a heading, the level should be set to 0 (the
        default).

        This function was introduced in Qt 5.12.

        **See also** **headingLevel** ().
        """
        ...

    def lineHeightType(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#lineHeightType

        **int QTextBlockFormat::lineHeightType() const**

        This returns the LineHeightType property of the paragraph.

        **See also** **LineHeightTypes** , **setLineHeight** (), and
        **lineHeight** ().
        """
        ...

    @typing.overload
    def lineHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#lineHeight

        **qreal QTextBlockFormat::lineHeight(qreal scriptLineHeight , qreal
        scaling = 1.0) const**

        Returns the height of the lines in the paragraph based on the height of
        the script line given by **scriptLineHeight** and the specified
        **scaling** factor.

        The value that is returned is also dependent on the given LineHeightType
        of the paragraph as well as the LineHeight setting that has been set for
        the paragraph.

        The scaling is needed for heights that include a fixed number of pixels,
        to scale them appropriately for printing.

        **See also** **LineHeightTypes** , **setLineHeight** (), and
        **lineHeightType** ().
        """
        ...

    @typing.overload
    def lineHeight(self, scriptLineHeight: float, scaling: float = ...) -> float:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#lineHeight-1

        **qreal QTextBlockFormat::lineHeight() const**

        This returns the LineHeight property for the paragraph.

        **See also** **LineHeightTypes** , **setLineHeight** (), and
        **lineHeightType** ().
        """
        ...

    def setLineHeight(self, height: float, heightType: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setLineHeight

        **void QTextBlockFormat::setLineHeight(qreal height , int heightType )**

        Sets the line height for the paragraph to the value given by **height**
        which is dependent on **heightType** in the way described by the
        **LineHeightTypes**  enum.

        **See also** **LineHeightTypes** , **lineHeight** (), and
        **lineHeightType** ().
        """
        ...

    def tabPositions(self) -> typing.List["QTextOption.Tab"]:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#tabPositions

        **QList<QTextOption::Tab> QTextBlockFormat::tabPositions() const**

        Returns a list of tab positions defined for the text block.

        **See also** **setTabPositions** ().
        """
        ...

    def setTabPositions(self, tabs: typing.Iterable["QTextOption.Tab"]) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setTabPositions

        **void QTextBlockFormat::setTabPositions(const QList<QTextOption::Tab> &
        tabs )**

        Sets the tab positions for the text block to those specified by
        **tabs**.

        **See also** **tabPositions** ().
        """
        ...

    def pageBreakPolicy(self) -> QTextFormat.PageBreakFlag:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#pageBreakPolicy

        **QTextFormat::PageBreakFlags QTextBlockFormat::pageBreakPolicy()
        const**

        Returns the currently set page break policy for the paragraph. The
        default is **QTextFormat::PageBreak_Auto** .

        **See also** **setPageBreakPolicy** ().
        """
        ...

    def setPageBreakPolicy(self, flags: QTextFormat.PageBreakFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setPageBreakPolicy

        **void QTextBlockFormat::setPageBreakPolicy(QTextFormat::PageBreakFlags
        policy )**

        Sets the page break policy for the paragraph to **policy**.

        **See also** **pageBreakPolicy** ().
        """
        ...

    def setIndent(self, aindent: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setIndent

        **void QTextBlockFormat::setIndent(int indentation )**

        Sets the paragraph's **indentation**. Margins are set independently of
        indentation with **setLeftMargin** () and **setTextIndent** (). The
        **indentation** is an integer that is multiplied with the document-wide
        standard indent, resulting in the actual indent of the paragraph.

        **See also** **indent** () and **QTextDocument::indentWidth** ().
        """
        ...

    def setAlignment(self, aalignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setAlignment

        **void QTextBlockFormat::setAlignment(Qt::Alignment alignment )**

        Sets the paragraph's **alignment**.

        **See also** **alignment** ().
        """
        ...

    def nonBreakableLines(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#nonBreakableLines

        **bool QTextBlockFormat::nonBreakableLines() const**

        Returns `true` if the lines in the paragraph are non-breakable;
        otherwise returns `false`.

        **See also** **setNonBreakableLines** ().
        """
        ...

    def setNonBreakableLines(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setNonBreakableLines

        **void QTextBlockFormat::setNonBreakableLines(bool b )**

        If **b** is true, the lines in the paragraph are treated as non-
        breakable; otherwise they are breakable.

        **See also** **nonBreakableLines** ().
        """
        ...

    def indent(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#indent

        **int QTextBlockFormat::indent() const**

        Returns the paragraph's indent.

        **See also** **setIndent** ().
        """
        ...

    def textIndent(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#textIndent

        **qreal QTextBlockFormat::textIndent() const**

        Returns the paragraph's text indent.

        **See also** **setTextIndent** ().
        """
        ...

    def setTextIndent(self, margin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setTextIndent

        **void QTextBlockFormat::setTextIndent(qreal indent )**

        Sets the **indent** for the first line in the block. This allows the
        first line of a paragraph to be indented differently to the other lines,
        enhancing the readability of the text.

        **See also** **textIndent** (), **setLeftMargin** (), **setRightMargin**
        (), **setTopMargin** (), and **setBottomMargin** ().
        """
        ...

    def rightMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#rightMargin

        **qreal QTextBlockFormat::rightMargin() const**

        Returns the paragraph's right margin.

        **See also** **setRightMargin** () and **leftMargin** ().
        """
        ...

    def setRightMargin(self, margin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setRightMargin

        **void QTextBlockFormat::setRightMargin(qreal margin )**

        Sets the paragraph's right **margin**.

        **See also** **rightMargin** (), **setLeftMargin** (), **setTopMargin**
        (), and **setBottomMargin** ().
        """
        ...

    def leftMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#leftMargin

        **qreal QTextBlockFormat::leftMargin() const**

        Returns the paragraph's left margin.

        **See also** **setLeftMargin** (), **rightMargin** (), and **indent**
        ().
        """
        ...

    def setLeftMargin(self, margin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setLeftMargin

        **void QTextBlockFormat::setLeftMargin(qreal margin )**

        Sets the paragraph's left **margin**. Indentation can be applied
        separately with **setIndent** ().

        **See also** **leftMargin** (), **setRightMargin** (), **setTopMargin**
        (), and **setBottomMargin** ().
        """
        ...

    def bottomMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#bottomMargin

        **qreal QTextBlockFormat::bottomMargin() const**

        Returns the paragraph's bottom margin.

        **See also** **setBottomMargin** () and **topMargin** ().
        """
        ...

    def setBottomMargin(self, margin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setBottomMargin

        **void QTextBlockFormat::setBottomMargin(qreal margin )**

        Sets the paragraph's bottom **margin**.

        **See also** **bottomMargin** (), **setTopMargin** (), **setLeftMargin**
        (), and **setRightMargin** ().
        """
        ...

    def topMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#topMargin

        **qreal QTextBlockFormat::topMargin() const**

        Returns the paragraph's top margin.

        **See also** **setTopMargin** () and **bottomMargin** ().
        """
        ...

    def setTopMargin(self, margin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#setTopMargin

        **void QTextBlockFormat::setTopMargin(qreal margin )**

        Sets the paragraph's top **margin**.

        **See also** **topMargin** (), **setBottomMargin** (), **setLeftMargin**
        (), and **setRightMargin** ().
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#alignment

        **Qt::Alignment QTextBlockFormat::alignment() const**

        Returns the paragraph's alignment.

        **See also** **setAlignment** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextblockformat.html#isValid

        **bool QTextBlockFormat::isValid() const**

        Returns `true` if this block format is valid; otherwise returns false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QSplashScreen(QWidget):
    """
    https://doc.qt.io/qt-6/qsplashscreen.html

    **Detailed Description**

    A splash screen is a widget that is usually displayed when an application is
    being started. Splash screens are often used for applications that have long
    start up times (e.g. database or networking applications that take time to
    establish connections) to provide the user with feedback that the
    application is loading.

    The splash screen appears in the center of the screen. It may be useful to
    add the **Qt::WindowStaysOnTopHint**  to the splash widget's window flags if
    you want to keep it above all the other windows on the desktop.

    Some X11 window managers do not support the "stays on top" flag. A solution
    is to set up a timer that periodically calls **raise** () on the splash
    screen to simulate the "stays on top" effect.

    The most common usage is to show a splash screen before the main widget is
    displayed on the screen. This is illustrated in the following code snippet
    in which a splash screen is displayed and some initialization tasks are
    performed before the application's main window is shown:

    int main(int argc, char *argv[])
        {
            **QApplication**  app(argc,
    argv);
            **QPixmap**  pixmap(":/splash.png");
    **QSplashScreen**  splash(pixmap);
            splash.show();
    app.processEvents();
            ...
            **QMainWindow**  window;
    window.show();
            splash.finish(&window);
            return app.exec();
    }

    The user can hide the splash screen by clicking on it with the mouse. Since
    the splash screen is typically displayed before the event loop has started
    running, it is necessary to periodically call
    **QCoreApplication::processEvents** () to receive the mouse clicks.

    It is sometimes useful to update the splash screen with messages, for
    example, announcing connections established or modules loaded as the
    application starts up:

    **QPixmap**  pixmap(":/splash.png");
        **QSplashScreen**  *splash = new
    **QSplashScreen** (pixmap);
        splash->show();

        ... // Loading some
    items
        splash->showMessage("Loaded modules");
    **QCoreApplication** ::processEvents();

        ... // Establishing
    connections
        splash->showMessage("Established connections");
    **QCoreApplication** ::processEvents();

    QSplashScreen supports this with the **showMessage** () function. If you
    wish to do your own drawing you can get a pointer to the pixmap used in the
    splash screen with **pixmap** (). Alternatively, you can subclass
    QSplashScreen and reimplement **drawContents** ().

    In case of having multiple screens, it is also possible to show the splash
    screen on a different screen than the primary one. For example:

    **QScreen**  *screen = **QGuiApplication** ::screens().at(1);
    **QPixmap**  pixmap(":/splash.png");
        **QSplashScreen**  splash(screen,
    pixmap);
        splash.show();
    """

    @typing.overload
    def __init__(
        self, pixmap: QtGui.QPixmap = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#QSplashScreen

        **QSplashScreen::QSplashScreen(const QPixmap & pixmap = QPixmap(),
        Qt::WindowFlags f = Qt::WindowFlags())**

        Construct a splash screen that will display the **pixmap**.

        There should be no need to set the widget flags, **f** , except perhaps
        **Qt::WindowStaysOnTopHint** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        screen: QtGui.QScreen,
        pixmap: QtGui.QPixmap = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#QSplashScreen-1

        **[since 5.15] QSplashScreen::QSplashScreen(QScreen * screen , const
        QPixmap & pixmap = QPixmap(), Qt::WindowFlags f = Qt::WindowFlags())**

        This is an overloaded function.

        This function allows you to specify the screen for your splashscreen.
        The typical use for this constructor is if you have multiple screens and
        prefer to have the splash screen on a different screen than your primary
        one. In that case pass the proper **screen**.

        This function was introduced in Qt 5.15.
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#mousePressEvent

        **[override virtual protected] void
        QSplashScreen::mousePressEvent(QMouseEvent *)**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#event

        **[override virtual protected] bool QSplashScreen::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def drawContents(self, painter: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#drawContents

        **[virtual protected] void QSplashScreen::drawContents(QPainter *
        painter )**

        Draw the contents of the splash screen using painter **painter**. The
        default implementation draws the message passed by **showMessage** ().
        Reimplement this function if you want to do your own drawing on the
        splash screen.
        """
        ...

    def clearMessage(self) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#clearMessage

        **[slot] void QSplashScreen::clearMessage()**

        Removes the message being displayed on the splash screen

        **See also** **showMessage** ().
        """
        ...

    def showMessage(
        self,
        message: str,
        alignment: int = ...,
        color: typing.Union[
            QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#showMessage

        **[slot] void QSplashScreen::showMessage(const QString & message , int
        alignment = Qt::AlignLeft, const QColor & color = Qt::black)**

        Draws the **message** text onto the splash screen with color **color**
        and aligns the text according to the flags in **alignment**. This
        function calls **repaint** () to make sure the splash screen is
        repainted immediately. As a result the message is kept up to date with
        what your application is doing (e.g. loading files).

        **See also** **Qt::Alignment** , **clearMessage** (), and **message**
        ().
        """
        ...

    def message(self) -> str:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#message

        **[since 5.2] QString QSplashScreen::message() const**

        Returns the message that is currently displayed on the splash screen.

        This function was introduced in Qt 5.2.

        **See also** **showMessage** () and **clearMessage** ().
        """
        ...

    def repaint(self) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#repaint

        **void QSplashScreen::repaint()**

        This overrides **QWidget::repaint** (). It differs from the standard
        repaint function in that it also calls
        **QCoreApplication::processEvents** () to ensure the updates are
        displayed, even when there is no event loop present.
        """
        ...

    def finish(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#finish

        **void QSplashScreen::finish(QWidget * mainWin )**

        Makes the splash screen wait until the widget **mainWin** is displayed
        before calling **close** () on itself.
        """
        ...

    def pixmap(self) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#pixmap

        **const QPixmap QSplashScreen::pixmap() const**

        Returns the pixmap that is used in the splash screen. The image does not
        have any of the text drawn by **showMessage** () calls.

        **See also** **setPixmap** ().
        """
        ...

    def setPixmap(self, pixmap: QtGui.QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#setPixmap

        **void QSplashScreen::setPixmap(const QPixmap & pixmap )**

        Sets the pixmap that will be used as the splash screen's image to
        **pixmap**.

        **See also** **pixmap** ().
        """
        ...

    @property
    def messageChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsplashscreen.html#messageChanged

        **[signal] void QSplashScreen::messageChanged(const QString & message
        )**

        This signal is emitted when the message on the splash screen changes.
        **message** is the new message and is a null-string when the message has
        been removed.

        **See also** **showMessage** () and **clearMessage** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QDBusAbstractAdaptor(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdbusabstractadaptor.html

    **Detailed Description**

    The QDBusAbstractAdaptor class is the starting point for all objects
    intending to provide interfaces to the external world using D-Bus. This is
    accomplished by attaching a one or more classes derived from
    QDBusAbstractAdaptor to a normal **QObject**  and then registering that
    **QObject**  with **QDBusConnection::registerObject** . QDBusAbstractAdaptor
    objects are intended to be light-weight wrappers, mostly just relaying calls
    into the real object (its parent) and the signals from it.

    Each QDBusAbstractAdaptor-derived class should define the D-Bus interface it
    is implementing using the **Q_CLASSINFO**  macro in the class definition.
    Note that only one interface can be exposed in this way.

    QDBusAbstractAdaptor uses the standard **QObject**  mechanism of signals,
    slots and properties to determine what signals, methods and properties to
    export to the bus. Any signal emitted by QDBusAbstractAdaptor-derived
    classes will be automatically be relayed through any D-Bus connections the
    object is registered on.

    Classes derived from QDBusAbstractAdaptor must be created on the heap using
    the **new** operator and must not be deleted by the user (they will be
    deleted automatically when the object they are connected to is also
    deleted).

    **See also** **Using adaptors**  and **QDBusConnection** .
    """

    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qdbusabstractadaptor.html#QDBusAbstractAdaptor

        **[protected] QDBusAbstractAdaptor::QDBusAbstractAdaptor(QObject * obj
        )**

        Constructs a QDBusAbstractAdaptor with **obj** as the parent object.
        """
        ...

    def autoRelaySignals(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusabstractadaptor.html#autoRelaySignals

        **[protected] bool QDBusAbstractAdaptor::autoRelaySignals() const**

        Returns `true` if automatic signal relaying from the real object (see
        object()) is enabled, otherwiser returns `false`.

        **See also** **setAutoRelaySignals** ().
        """
        ...

    def setAutoRelaySignals(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdbusabstractadaptor.html#setAutoRelaySignals

        **[protected] void QDBusAbstractAdaptor::setAutoRelaySignals(bool enable
        )**

        Toggles automatic signal relaying from the real object (see object()).

        Automatic signal relaying consists of signal-to-signal connection of the
        signals on the parent that have the exact same method signature in both
        classes.

        If **enable** is set to true, connect the signals; if set to false,
        disconnect all signals.

        **See also** **autoRelaySignals** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QStorageInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qstorageinfo.html

    **Detailed Description**

    Allows retrieving information about the volume's space, its mount point,
    label, and filesystem name.

    You can create an instance of QStorageInfo by passing the path to the
    volume's mount point as a constructor parameter, or you can set it using the
    **setPath** () method. The static **mountedVolumes** () method can be used
    to get the list of all mounted filesystems.

    QStorageInfo always caches the retrieved information, but you can call
    **refresh** () to invalidate the cache.

    The following example retrieves the most common information about the root
    volume of the system, and prints information about it.

    **QStorageInfo**  storage = **QStorageInfo** ::root();
    **qDebug** () << storage.rootPath();
            if (storage.isReadOnly())
    **qDebug** () << "isReadOnly:" << storage.isReadOnly();
    **qDebug** () << "name:" << storage.name();
            **qDebug** () <<
    "fileSystemType:" << storage.fileSystemType();
            **qDebug** () <<
    "size:" << storage.bytesTotal()/1000/1000 << "MB";
            **qDebug** () <<
    "availableSize:" << storage.bytesAvailable()/1000/1000 << "MB";
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#QStorageInfo

        **QStorageInfo::QStorageInfo()**

        Constructs an empty QStorageInfo object.

        Objects created with the default constructor will be invalid and
        therefore not ready for use.

        **See also** **setPath** (), **isReady** (), and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, path: str) -> None:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#QStorageInfo-1

        **QStorageInfo::QStorageInfo(const QString & path )**

        Constructs a new QStorageInfo object that gives information about the
        volume mounted at **path**.

        If you pass a directory or file, the QStorageInfo object will refer to
        the volume where this directory or file is located. You can check if the
        created object is correct using the **isValid** () method.

        The following example shows how to get the volume on which the
        application is located. It is recommended to always check that the
        volume is ready and valid.

        **QStorageInfo**  storage(**qApp** ->applicationDirPath());
                if
        (storage.isValid() && storage.isReady()) {
                    // ...
                }

        **See also** **setPath** ().
        """
        ...

    @typing.overload
    def __init__(self, dir: QDir) -> None:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#QStorageInfo-2

        **QStorageInfo::QStorageInfo(const QDir & dir )**

        Constructs a new QStorageInfo object that gives information about the
        volume containing the **dir** folder.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStorageInfo") -> None:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#QStorageInfo-3

        **QStorageInfo::QStorageInfo(const QStorageInfo & other )**

        Constructs a new QStorageInfo object that is a copy of the **other**
        QStorageInfo object.
        """
        ...

    def subvolume(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#subvolume

        **[since 5.9] QByteArray QStorageInfo::subvolume() const**

        Returns the subvolume name for this volume.

        Some filesystem types allow multiple subvolumes inside one device, which
        may be mounted in different paths. If the subvolume could be detected,
        it is returned here. The format of the subvolume name is specific to
        each filesystem type.

        If this volume was not mounted from a subvolume of a larger filesystem
        or if the subvolume could not be detected, this function returns an
        empty byte array.

        This function was introduced in Qt 5.9.

        **See also** **device** ().
        """
        ...

    def blockSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#blockSize

        **[since 5.6] int QStorageInfo::blockSize() const**

        Returns the optimal transfer block size for this filesystem.

        Returns -1 if **QStorageInfo**  could not determine the size or if the
        **QStorageInfo**  object is not valid.

        This function was introduced in Qt 5.6.
        """
        ...

    def isRoot(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#isRoot

        **bool QStorageInfo::isRoot() const**

        Returns true if this **QStorageInfo**  represents the system root
        volume; false otherwise.

        On Unix filesystems, the root volume is a volume mounted on `/`. On
        Windows, the root volume is the volume where the OS is installed.

        **See also** **root** ().
        """
        ...

    @staticmethod
    def root() -> "QStorageInfo":
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#root

        **[static] QStorageInfo QStorageInfo::root()**

        Returns a **QStorageInfo**  object that represents the system root
        volume.

        On Unix systems this call returns the root ('/') volume; in Windows the
        volume where the operating system is installed.

        **See also** **isRoot** ().
        """
        ...

    @staticmethod
    def mountedVolumes() -> typing.List["QStorageInfo"]:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#mountedVolumes

        **[static] QList<QStorageInfo> QStorageInfo::mountedVolumes()**

        Returns the list of **QStorageInfo**  objects that corresponds to the
        list of currently mounted filesystems.

        On Windows, this returns the drives visible in the **My Computer**
        folder. On Unix operating systems, it returns the list of all mounted
        filesystems (except for pseudo filesystems).

        Returns all currently mounted filesystems by default.

        The example shows how to retrieve all available filesystems, skipping
        read-only ones.

        foreach (const **QStorageInfo**  &storage, **QStorageInfo**
        ::mountedVolumes()) {
                    if (storage.isValid() &&
        storage.isReady()) {
                        if (!storage.isReadOnly()) {
        // ...
                        }
                    }
                }

        **See also** **root** ().
        """
        ...

    def refresh(self) -> None:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#refresh

        **void QStorageInfo::refresh()**

        Resets **QStorageInfo** 's internal cache.

        **QStorageInfo**  caches information about storage to speed up
        performance. **QStorageInfo**  retrieves information during object
        construction and/or when calling the **setPath** () method. You have to
        manually reset the cache by calling this function to update storage
        information.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#isValid

        **bool QStorageInfo::isValid() const**

        Returns true if the **QStorageInfo**  specified by **rootPath**  exists
        and is mounted correctly.

        **See also** **isReady** ().
        """
        ...

    def isReady(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#isReady

        **bool QStorageInfo::isReady() const**

        Returns true if the current filesystem is ready to work; false
        otherwise. For example, false is returned if the CD volume is not
        inserted.

        Note that **fileSystemType** (), **name** (), **bytesTotal** (),
        **bytesFree** (), and **bytesAvailable** () will return invalid data
        until the volume is ready.

        **See also** **isValid** ().
        """
        ...

    def isReadOnly(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#isReadOnly

        **bool QStorageInfo::isReadOnly() const**

        Returns true if the current filesystem is protected from writing; false
        otherwise.
        """
        ...

    def bytesAvailable(self) -> int:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#bytesAvailable

        **qint64 QStorageInfo::bytesAvailable() const**

        Returns the size (in bytes) available for the current user. It returns
        the total size available if the user is the root user or a system
        administrator.

        This size can be less than or equal to the free size returned by
        **bytesFree** () function.

        Returns -1 if **QStorageInfo**  object is not valid.

        **See also** **bytesTotal** () and **bytesFree** ().
        """
        ...

    def bytesFree(self) -> int:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#bytesFree

        **qint64 QStorageInfo::bytesFree() const**

        Returns the number of free bytes in a volume. Note that if there are
        quotas on the filesystem, this value can be larger than the value
        returned by **bytesAvailable** ().

        Returns -1 if **QStorageInfo**  object is not valid.

        **See also** **bytesTotal** () and **bytesAvailable** ().
        """
        ...

    def bytesTotal(self) -> int:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#bytesTotal

        **qint64 QStorageInfo::bytesTotal() const**

        Returns the total volume size in bytes.

        Returns -1 if **QStorageInfo**  object is not valid.

        **See also** **bytesFree** () and **bytesAvailable** ().
        """
        ...

    def displayName(self) -> str:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#displayName

        **QString QStorageInfo::displayName() const**

        Returns the volume's name, if available, or the root path if not.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#name

        **QString QStorageInfo::name() const**

        Returns the human-readable name of a filesystem, usually called `label`.

        Not all filesystems support this feature. In this case, the value
        returned by this method could be empty. An empty string is returned if
        the file system does not support labels, or if no label is set.

        On Linux, retrieving the volume's label requires `udev` to be present in
        the system.

        **See also** **fileSystemType** ().
        """
        ...

    def fileSystemType(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#fileSystemType

        **QByteArray QStorageInfo::fileSystemType() const**

        Returns the type name of the filesystem.

        This is a platform-dependent function, and filesystem names can vary
        between different operating systems. For example, on Windows filesystems
        they can be named `NTFS`, and on Linux they can be named `ntfs-3g` or
        `fuseblk`.

        **See also** **name** ().
        """
        ...

    def device(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#device

        **QByteArray QStorageInfo::device() const**

        Returns the device for this volume.

        For example, on Unix filesystems (including macOS), this returns the
        devpath like `/dev/sda0` for local storages. On Windows, it returns the
        UNC path starting with `\\\\\\\\?\\\\` for local storages (in other words, the
        volume GUID).

        **See also** **rootPath** () and **subvolume** ().
        """
        ...

    def rootPath(self) -> str:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#rootPath

        **QString QStorageInfo::rootPath() const**

        Returns the mount point of the filesystem this **QStorageInfo**  object
        represents.

        On Windows, it returns the volume letter in case the volume is not
        mounted to a directory.

        Note that the value returned by rootPath() is the real mount point of a
        volume, and may not be equal to the value passed to the constructor or
        **setPath** () method. For example, if you have only the root volume in
        the system, and pass '/directory' to **setPath** (), then this method
        will return '/'.

        **See also** **setPath** () and **device** ().
        """
        ...

    def setPath(self, path: str) -> None:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#setPath

        **void QStorageInfo::setPath(const QString & path )**

        Sets this **QStorageInfo**  object to the filesystem mounted where
        **path** is located.

        **path** can either be a root path of the filesystem, a directory, or a
        file within that filesystem.

        **See also** **rootPath** ().
        """
        ...

    def swap(self, other: "QStorageInfo") -> None:
        """
        https://doc.qt.io/qt-6/qstorageinfo.html#swap

        **void QStorageInfo::swap(QStorageInfo & other )**

        Swaps this volume info with **other**. This function is very fast and
        never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QEnterEvent(QSinglePointEvent):
    """
    https://doc.qt.io/qt-6/qenterevent.html

    **Detailed Description**

    Enter events occur when the mouse cursor enters a window or a widget.
    """

    def __init__(
        self,
        localPos: QtCore.QPointF,
        scenePos: QtCore.QPointF,
        globalPos: QtCore.QPointF,
        device: typing.Optional["QPointingDevice"] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qenterevent.html#QEnterEvent-2

        **QEnterEvent::QEnterEvent(const QPointF & localPos , const QPointF &
        scenePos , const QPointF & globalPos , const QPointingDevice * device =
        QPointingDevice::primaryPointingDevice())**

        Constructs an enter event object originating from **device**.

        The points **localPos** , **scenePos** and **globalPos** specify the
        mouse cursor's position relative to the receiving widget or item,
        window, and screen or desktop, respectively.
        """
        ...

    def clone(self) -> "QEnterEvent":
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
import datetime
from PyQt6.QtNetwork import *
import enum


class QNetworkCookie(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkcookie.html

    **Detailed Description**

    Cookies are small bits of information that stateless protocols like HTTP use
    to maintain some persistent information across requests.

    A cookie is set by a remote server when it replies to a request and it
    expects the same cookie to be sent back when further requests are sent.

    QNetworkCookie holds one such cookie as received from the network. A cookie
    has a name and a value, but those are opaque to the application (that is,
    the information stored in them has no meaning to the application). A cookie
    has an associated path name and domain, which indicate when the cookie
    should be sent again to the server.

    A cookie can also have an expiration date, indicating its validity. If the
    expiration date is not present, the cookie is considered a "session cookie"
    and should be discarded when the application exits (or when its concept of
    session is over).

    QNetworkCookie provides a way of parsing a cookie from the HTTP header
    format using the **QNetworkCookie::parseCookies** () function. However, when
    received in a **QNetworkReply** , the cookie is already parsed.

    This class implements cookies as described by the **initial cookie
    specification by Netscape** , which is somewhat similar to the **RFC 2109**
    specification, plus the **"HttpOnly" extension** . The more recent **RFC
    2965**  specification (which uses the Set-Cookie2 header) is not supported.

    **See also** **QNetworkCookieJar** , **QNetworkRequest** , and
    **QNetworkReply** .
    """

    class SameSite(enum.Enum):
        Default: QNetworkCookie = ...
        None_: QNetworkCookie = ...
        Lax: QNetworkCookie = ...
        Strict: QNetworkCookie = ...

    class RawForm(enum.Enum):
        NameAndValueOnly: QNetworkCookie = ...
        Full: QNetworkCookie = ...

    @typing.overload
    def __init__(
        self, name: QtCore.QByteArray = ..., value: QtCore.QByteArray = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#QNetworkCookie

        **QNetworkCookie::QNetworkCookie(const QByteArray & name = QByteArray(),
        const QByteArray & value = QByteArray())**

        Create a new QNetworkCookie object, initializing the cookie name to
        **name** and its value to **value**.

        A cookie is only valid if it has a name. However, the value is opaque to
        the application and being empty may have significance to the remote
        server.
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkCookie") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#QNetworkCookie-1

        **QNetworkCookie::QNetworkCookie(const QNetworkCookie & other )**

        Creates a new QNetworkCookie object by copying the contents of
        **other**.
        """
        ...

    def setSameSitePolicy(self, sameSite: "QNetworkCookie.SameSite") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setSameSitePolicy

        **[since 6.1] void
        QNetworkCookie::setSameSitePolicy(QNetworkCookie::SameSite sameSite )**

        Sets the "**SameSite** " option of this cookie to **sameSite**.

        This function was introduced in Qt 6.1.

        **See also** **sameSitePolicy** ().
        """
        ...

    def sameSitePolicy(self) -> "QNetworkCookie.SameSite":
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#sameSitePolicy

        **[since 6.1] QNetworkCookie::SameSite QNetworkCookie::sameSitePolicy()
        const**

        Returns the "**SameSite** " option if specified in the cookie string,
        `SameSite::Default` if not present.

        This function was introduced in Qt 6.1.

        **See also** **setSameSitePolicy** ().
        """
        ...

    def normalize(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#normalize

        **[since 5.0] void QNetworkCookie::normalize(const QUrl & url )**

        This functions normalizes the path and domain of the cookie if they were
        previously empty. The **url** parameter is used to determine the correct
        domain and path.

        This function was introduced in Qt 5.0.
        """
        ...

    def hasSameIdentifier(self, other: "QNetworkCookie") -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#hasSameIdentifier

        **bool QNetworkCookie::hasSameIdentifier(const QNetworkCookie & other )
        const**

        Returns `true` if this cookie has the same identifier tuple as
        **other**. The identifier tuple is composed of the name, domain and
        path.

        **See also** **operator==** ().
        """
        ...

    def swap(self, other: "QNetworkCookie") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#swap

        **[since 5.0] void QNetworkCookie::swap(QNetworkCookie & other )**

        Swaps this cookie with **other**. This function is very fast and never
        fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def setHttpOnly(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setHttpOnly

        **void QNetworkCookie::setHttpOnly(bool enable )**

        Sets this cookie's "HttpOnly" flag to **enable**.

        **See also** **isHttpOnly** ().
        """
        ...

    def isHttpOnly(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#isHttpOnly

        **bool QNetworkCookie::isHttpOnly() const**

        Returns `true` if the "HttpOnly" flag is enabled for this cookie.

        A cookie that is "HttpOnly" is only set and retrieved by the network
        requests and replies; i.e., the HTTP protocol. It is not accessible from
        scripts running on browsers.

        **See also** **isSecure** ().
        """
        ...

    @staticmethod
    def parseCookies(cookieString: QtCore.QByteArray) -> typing.List["QNetworkCookie"]:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#parseCookies

        **[static] QList<QNetworkCookie> QNetworkCookie::parseCookies(const
        QByteArray & cookieString )**

        Parses the cookie string **cookieString** as received from a server
        response in the "Set-Cookie:" header. If there's a parsing error, this
        function returns an empty list.

        Since the HTTP header can set more than one cookie at the same time,
        this function returns a **QList** <**QNetworkCookie** >, one for each
        cookie that is parsed.

        **See also** **toRawForm** ().
        """
        ...

    def toRawForm(self, form: "QNetworkCookie.RawForm" = ...) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#toRawForm

        **QByteArray QNetworkCookie::toRawForm(QNetworkCookie::RawForm form =
        Full) const**

        Returns the raw form of this **QNetworkCookie** . The **QByteArray**
        returned by this function is suitable for an HTTP header, either in a
        server response (the Set-Cookie header) or the client request (the
        Cookie header). You can choose from one of two formats, using **form**.

        **See also** **parseCookies** ().
        """
        ...

    def setValue(self, value: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setValue

        **void QNetworkCookie::setValue(const QByteArray & value )**

        Sets the value of this cookie to be **value**.

        **See also** **value** () and **name** ().
        """
        ...

    def value(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#value

        **QByteArray QNetworkCookie::value() const**

        Returns this cookies value, as specified in the cookie string. Note that
        a cookie is still valid if its value is empty.

        Cookie name-value pairs are considered opaque to the application: that
        is, their values don't mean anything.

        **See also** **setValue** () and **name** ().
        """
        ...

    def setName(self, cookieName: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setName

        **void QNetworkCookie::setName(const QByteArray & cookieName )**

        Sets the name of this cookie to be **cookieName**. Note that setting a
        cookie name to an empty **QByteArray**  will make this cookie invalid.

        **See also** **name** () and **value** ().
        """
        ...

    def name(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#name

        **QByteArray QNetworkCookie::name() const**

        Returns the name of this cookie. The only mandatory field of a cookie is
        its name, without which it is not considered valid.

        **See also** **setName** () and **value** ().
        """
        ...

    def setPath(self, path: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setPath

        **void QNetworkCookie::setPath(const QString & path )**

        Sets the path associated with this cookie to be **path**.

        **See also** **path** ().
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#path

        **QString QNetworkCookie::path() const**

        Returns the path associated with this cookie. This corresponds to the
        "path" field of the cookie string.

        **See also** **setPath** ().
        """
        ...

    def setDomain(self, domain: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setDomain

        **void QNetworkCookie::setDomain(const QString & domain )**

        Sets the domain associated with this cookie to be **domain**.

        **See also** **domain** ().
        """
        ...

    def domain(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#domain

        **QString QNetworkCookie::domain() const**

        Returns the domain this cookie is associated with. This corresponds to
        the "domain" field of the cookie string.

        Note that the domain here may start with a dot, which is not a valid
        hostname. However, it means this cookie matches all hostnames ending
        with that domain name.

        **See also** **setDomain** ().
        """
        ...

    def setExpirationDate(
        self, date: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setExpirationDate

        **void QNetworkCookie::setExpirationDate(const QDateTime & date )**

        Sets the expiration date of this cookie to **date**. Setting an invalid
        expiration date to this cookie will mean it's a session cookie.

        **See also** **isSessionCookie** () and **expirationDate** ().
        """
        ...

    def expirationDate(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#expirationDate

        **QDateTime QNetworkCookie::expirationDate() const**

        Returns the expiration date for this cookie. If this cookie is a session
        cookie, the **QDateTime**  returned will not be valid. If the date is in
        the past, this cookie has already expired and should not be sent again
        back to a remote server.

        The expiration date corresponds to the parameters of the "expires" entry
        in the cookie string.

        **See also** **isSessionCookie** () and **setExpirationDate** ().
        """
        ...

    def isSessionCookie(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#isSessionCookie

        **bool QNetworkCookie::isSessionCookie() const**

        Returns `true` if this cookie is a session cookie. A session cookie is a
        cookie which has no expiration date, which means it should be discarded
        when the application's concept of session is over (usually, when the
        application exits).

        **See also** **expirationDate** () and **setExpirationDate** ().
        """
        ...

    def setSecure(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#setSecure

        **void QNetworkCookie::setSecure(bool enable )**

        Sets the secure flag of this cookie to **enable**.

        Secure cookies may contain private information and should not be resent
        over unencrypted connections.

        **See also** **isSecure** ().
        """
        ...

    def isSecure(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkcookie.html#isSecure

        **bool QNetworkCookie::isSecure() const**

        Returns `true` if the "secure" option was specified in the cookie
        string, false otherwise.

        Secure cookies may contain private information and should not be resent
        over unencrypted connections.

        **See also** **setSecure** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QTemporaryFile(QFile):
    """
    https://doc.qt.io/qt-6/qtemporaryfile.html

    **Detailed Description**

    QTemporaryFile is used to create unique temporary files safely. The file
    itself is created by calling **open** (). The name of the temporary file is
    guaranteed to be unique (i.e., you are guaranteed to not overwrite an
    existing file), and the file will subsequently be removed upon destruction
    of the QTemporaryFile object. This is an important technique that avoids
    data corruption for applications that store data in temporary files. The
    file name is either auto-generated, or created based on a template, which is
    passed to QTemporaryFile's constructor.

    Example:

    // Within a function/method...

            **QTemporaryFile**  file;
    if (file.open()) {
                // file.fileName() returns the unique file
    name
            }

            // The QTemporaryFile destructor removes the
    temporary file
            // as it goes out of scope.

    Reopening a QTemporaryFile after calling **close** () is safe. For as long
    as the QTemporaryFile object itself is not destroyed, the unique temporary
    file will exist and be kept open internally by QTemporaryFile.

    The file name of the temporary file can be found by calling **fileName** ().
    Note that this is only defined after the file is first opened; the function
    returns an empty string before this.

    A temporary file will have some static part of the name and some part that
    is calculated to be unique. The default filename will be determined from
    **QCoreApplication::applicationName** () (otherwise `qt_temp`) and will be
    placed into the temporary path as returned by **QDir::tempPath** (). If you
    specify your own filename, a relative file path will not be placed in the
    temporary directory by default, but be relative to the current working
    directory.

    Specified filenames can contain the following template `XXXXXX` (six upper
    case "X" characters), which will be replaced by the auto-generated portion
    of the filename. Note that the template is case sensitive. If the template
    is not present in the filename, QTemporaryFile appends the generated part to
    the filename given.

    **Note:** On Linux, QTemporaryFile will attempt to create unnamed temporary
    files. If that succeeds, **open** () will return true but **exists** () will
    be false. If you call **fileName** () or any function that calls it,
    QTemporaryFile will give the file a name, so most applications will not see
    a difference.

    **See also** **QDir::tempPath** () and **QFile** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#QTemporaryFile

        **QTemporaryFile::QTemporaryFile()**

        Constructs a QTemporaryFile using as file template the application name
        returned by **QCoreApplication::applicationName** () (otherwise
        `qt_temp`) followed by ".XXXXXX". The file is stored in the system's
        temporary directory, **QDir::tempPath** ().

        **See also** **setFileTemplate** () and **QDir::tempPath** ().
        """
        ...

    @typing.overload
    def __init__(self, templateName: str) -> None:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#QTemporaryFile-1

        **QTemporaryFile::QTemporaryFile(const QString & templateName )**

        Constructs a QTemporaryFile with a template filename of
        **templateName**. Upon opening the temporary file this will be used to
        create a unique filename.

        If the **templateName** does not contain XXXXXX it will automatically be
        appended and used as the dynamic portion of the filename.

        If **templateName** is a relative path, the path will be relative to the
        current working directory. You can use **QDir::tempPath** () to
        construct **templateName** if you want use the system's temporary
        directory.

        **See also** **open** () and **fileTemplate** ().
        """
        ...

    @typing.overload
    def __init__(self, parent: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#QTemporaryFile-2

        **QTemporaryFile::QTemporaryFile(QObject * parent )**

        Constructs a QTemporaryFile (with the given **parent** ) using as file
        template the application name returned by
        **QCoreApplication::applicationName** () (otherwise `qt_temp`) followed
        by ".XXXXXX". The file is stored in the system's temporary directory,
        **QDir::tempPath** ().

        **See also** **setFileTemplate** ().
        """
        ...

    @typing.overload
    def __init__(self, templateName: str, parent: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#QTemporaryFile-3

        **QTemporaryFile::QTemporaryFile(const QString & templateName , QObject
        * parent )**

        Constructs a QTemporaryFile with a template filename of **templateName**
        and the specified **parent**. Upon opening the temporary file this will
        be used to create a unique filename.

        If the **templateName** does not contain XXXXXX it will automatically be
        appended and used as the dynamic portion of the filename.

        If **templateName** is a relative path, the path will be relative to the
        current working directory. You can use **QDir::tempPath** () to
        construct **templateName** if you want use the system's temporary
        directory.

        **See also** **open** () and **fileTemplate** ().
        """
        ...

    def rename(self, newName: str) -> bool:
        ...

    @typing.overload
    @staticmethod
    def createNativeFile(fileName: str) -> "QTemporaryFile":
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#createNativeFile

        **[static] QTemporaryFile *QTemporaryFile::createNativeFile(QFile & file
        )**

        If **file** is not already a native file, then a **QTemporaryFile**  is
        created in **QDir::tempPath** (), the contents of **file** is copied
        into it, and a pointer to the temporary file is returned. Does nothing
        and returns `0` if **file** is already a native file.

        For example:

        **QFile**  f(":/resources/file.txt");
              **QTemporaryFile**
        ::createNativeFile(f); // Returns a pointer to a temporary file
        **QFile**  f("/users/qt/file.txt");
              **QTemporaryFile**
        ::createNativeFile(f); // Returns 0

        **See also** **QFileInfo::isNativePath** ().
        """
        ...

    @typing.overload
    @staticmethod
    def createNativeFile(file: QFile) -> "QTemporaryFile":
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#createNativeFile-1

        **[static] QTemporaryFile *QTemporaryFile::createNativeFile(const
        QString & fileName )**

        This is an overloaded function.

        Works on the given **fileName** rather than an existing **QFile**
        object.
        """
        ...

    def setFileTemplate(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#setFileTemplate

        **void QTemporaryFile::setFileTemplate(const QString & name )**

        Sets the static portion of the file name to **name**. If the file
        template contains XXXXXX that will automatically be replaced with the
        unique part of the filename, otherwise a filename will be determined
        automatically based on the static portion specified.

        If **name** contains a relative file path, the path will be relative to
        the current working directory. You can use **QDir::tempPath** () to
        construct **name** if you want use the system's temporary directory.

        **See also** **fileTemplate** ().
        """
        ...

    def fileTemplate(self) -> str:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#fileTemplate

        **QString QTemporaryFile::fileTemplate() const**

        Returns the set file template. The default file template will be called
        qcoreappname.XXXXXX and be placed in **QDir::tempPath** ().

        **See also** **setFileTemplate** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#fileName

        **[override virtual] QString QTemporaryFile::fileName() const**

        Reimplements: **QFile::fileName() const** .

        Returns the complete unique filename backing the **QTemporaryFile**
        object. This string is null before the **QTemporaryFile**  is opened,
        afterwards it will contain the **fileTemplate** () plus additional
        characters to make it unique.

        **See also** **fileTemplate** ().
        """
        ...

    @typing.overload
    def open(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#open

        **bool QTemporaryFile::open()**

        A **QTemporaryFile**  will always be opened in QIODevice::ReadWrite
        mode, this allows easy access to the data in the file. This function
        will return true upon success and will set the **fileName** () to the
        unique filename used.

        **See also** **fileName** ().
        """
        ...

    @typing.overload
    def open(self, flags: QIODeviceBase.OpenModeFlag) -> bool:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#open-1

        **[override virtual protected] bool
        QTemporaryFile::open(QIODeviceBase::OpenMode flags )**

        Reimplements: **QFile::open** (QIODeviceBase::OpenMode mode).

        Creates a unique file name for the temporary file, and opens it. You can
        get the unique name later by calling **fileName** (). The file is
        guaranteed to have been created by this function (i.e., it has never
        existed before).
        """
        ...

    def setAutoRemove(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#setAutoRemove

        **void QTemporaryFile::setAutoRemove(bool b )**

        Sets the **QTemporaryFile**  into auto-remove mode if **b** is `true`.

        Auto-remove is on by default.

        If you set this property to `false`, ensure the application provides a
        way to remove the file once it is no longer needed, including passing
        the responsibility on to another process. Always use the **fileName** ()
        function to obtain the name and never try to guess the name that
        **QTemporaryFile**  has generated.

        On some systems, if **fileName** () is not called before closing the
        file, the temporary file may be removed regardless of the state of this
        property. This behavior should not be relied upon, so application code
        should either call **fileName** () or leave the auto removal
        functionality enabled.

        **See also** **autoRemove** () and **remove** ().
        """
        ...

    def autoRemove(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtemporaryfile.html#autoRemove

        **bool QTemporaryFile::autoRemove() const**

        Returns `true` if the **QTemporaryFile**  is in auto remove mode. Auto-
        remove mode will automatically delete the filename from disk upon
        destruction. This makes it very easy to create your **QTemporaryFile**
        object on the stack, fill it with data, read from it, and finally on
        function return it will automatically clean up after itself.

        Auto-remove is on by default.

        **See also** **setAutoRemove** () and **remove** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QGraphicsSceneContextMenuEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenecontextmenuevent.html

    **Detailed Description**

    A **QContextMenuEvent**  received by a **QGraphicsView**  is translated into
    a QGraphicsSceneContextMenuEvent. The **QContextMenuEvent::globalPos** () is
    translated into item, scene, and screen coordinates (**pos** (),
    **scenePos** (), and **screenPos** ()).

    **See also** **QGraphicsSceneMouseEvent** , **QGraphicsSceneWheelEvent** ,
    and **QContextMenuEvent** .
    """

    class Reason(enum.Enum):
        Mouse: QGraphicsSceneContextMenuEvent = ...
        Keyboard: QGraphicsSceneContextMenuEvent = ...
        Other: QGraphicsSceneContextMenuEvent = ...

    def reason(self) -> "QGraphicsSceneContextMenuEvent.Reason":
        """
        https://doc.qt.io/qt-6/qgraphicsscenecontextmenuevent.html#reason

        **QGraphicsSceneContextMenuEvent::Reason
        QGraphicsSceneContextMenuEvent::reason() const**

        Returns the reason for the context menu event.

        **See also** **QGraphicsSceneContextMenuEvent::Reason** .
        """
        ...

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qgraphicsscenecontextmenuevent.html#modifiers

        **Qt::KeyboardModifiers QGraphicsSceneContextMenuEvent::modifiers()
        const**

        Returns the keyboard modifiers in use when the context menu was
        requested.
        """
        ...

    def screenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenecontextmenuevent.html#screenPos

        **QPoint QGraphicsSceneContextMenuEvent::screenPos() const**

        Returns the position of the mouse cursor in screen coordinates at the
        moment the context menu was requested.

        **See also** **pos** () and **scenePos** ().
        """
        ...

    def scenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenecontextmenuevent.html#scenePos

        **QPointF QGraphicsSceneContextMenuEvent::scenePos() const**

        Returns the position of the mouse cursor in scene coordinates at the
        moment the context menu was requested.

        **See also** **pos** () and **screenPos** ().
        """
        ...

    def pos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenecontextmenuevent.html#pos

        **QPointF QGraphicsSceneContextMenuEvent::pos() const**

        Returns the position of the mouse cursor in item coordinates at the
        moment the context menu was requested.

        **See also** **scenePos** () and **screenPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QGesture(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qgesture.html

    **Detailed Description**

    Gesture objects are not constructed directly by developers. They are created
    by the **QGestureRecognizer**  object that is registered with the
    application; see **QGestureRecognizer::registerRecognizer** ().

    For an overview of gesture handling in Qt and information on using gestures
    in your applications, see the **Gestures in Widgets and Graphics View**
    document.

    **Gesture Properties**

    The class has a list of properties that can be queried by the user to get
    some gesture-specific arguments. For example, the pinch gesture has a scale
    factor that is exposed as a property.

    Developers of custom gesture recognizers can add additional properties in
    order to provide additional information about a gesture. This can be done by
    adding new dynamic properties to a QGesture object, or by subclassing the
    QGesture class (or one of its subclasses).

    **Lifecycle of a Gesture Object**

    A QGesture instance is implicitly created when needed and is owned by Qt.
    Developers should never destroy them or store them for later use as Qt may
    destroy particular instances of them and create new ones to replace them.

    The registered gesture recognizer monitors the input events for the target
    object via its **recognize** () function, updating the properties of the
    gesture object as required.

    The gesture object may be delivered to the target object in a
    **QGestureEvent**  if the corresponding gesture is active or has just been
    canceled. Each event that is delivered contains a list of gesture objects,
    since support for more than one gesture may be enabled for the target
    object. Due to the way events are handled in Qt, gesture events may be
    filtered by other objects.

    **See also** **QGestureEvent**  and **QGestureRecognizer** .
    """

    class GestureCancelPolicy(enum.Enum):
        CancelNone: QGesture = ...
        CancelAllInContext: QGesture = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgesture.html#QGesture

        **QGesture::QGesture(QObject * parent = nullptr)**

        Constructs a new gesture object with the given **parent**.

        QGesture objects are created by gesture recognizers in the
        **QGestureRecognizer::create** () function.
        """
        ...

    def gestureCancelPolicy(self) -> "QGesture.GestureCancelPolicy":
        """
        https://doc.qt.io/qt-6/qgesture.html#gestureCancelPolicy-prop

        **gestureCancelPolicy : QGesture::GestureCancelPolicy**

        This property holds the policy for deciding what happens on accepting a
        gesture

        On accepting one gesture Qt can automatically cancel other gestures that
        belong to other targets. The policy is normally set to not cancel any
        other gestures and can be set to cancel all active gestures in the
        context. For example for all child widgets.

        **Access functions:**

        QGesture::GestureCancelPolicy **gestureCancelPolicy** () const
        void
        **setGestureCancelPolicy** (QGesture::GestureCancelPolicy **policy** )
        """
        ...

    def setGestureCancelPolicy(self, policy: "QGesture.GestureCancelPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qgesture.html#gestureCancelPolicy-prop

        **gestureCancelPolicy : QGesture::GestureCancelPolicy**

        This property holds the policy for deciding what happens on accepting a
        gesture

        On accepting one gesture Qt can automatically cancel other gestures that
        belong to other targets. The policy is normally set to not cancel any
        other gestures and can be set to cancel all active gestures in the
        context. For example for all child widgets.

        **Access functions:**

        QGesture::GestureCancelPolicy **gestureCancelPolicy** () const
        void
        **setGestureCancelPolicy** (QGesture::GestureCancelPolicy **policy** )
        """
        ...

    def unsetHotSpot(self) -> None:
        ...

    def hasHotSpot(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgesture.html#hasHotSpot-prop

        **[read-only] hasHotSpot : const bool**

        This property holds whether the gesture has a hot-spot

        **Access functions:**

        bool **hasHotSpot** () const
        """
        ...

    def setHotSpot(self, value: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qgesture.html#hotSpot-prop

        **hotSpot : QPointF**

        This property holds the point that is used to find the receiver for the
        gesture event.

        The hot-spot is a point in the global coordinate system, use
        **QWidget::mapFromGlobal** () or **QGestureEvent::mapToGraphicsScene**
        () to get a local hot-spot.

        The hot-spot should be set by the gesture recognizer to allow gesture
        event delivery to a **QGraphicsObject** .

        **Access functions:**

        QPointF **hotSpot** () const
        void **setHotSpot** (const QPointF &
        **value** )
        void **unsetHotSpot** ()
        """
        ...

    def hotSpot(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgesture.html#hotSpot-prop

        **hotSpot : QPointF**

        This property holds the point that is used to find the receiver for the
        gesture event.

        The hot-spot is a point in the global coordinate system, use
        **QWidget::mapFromGlobal** () or **QGestureEvent::mapToGraphicsScene**
        () to get a local hot-spot.

        The hot-spot should be set by the gesture recognizer to allow gesture
        event delivery to a **QGraphicsObject** .

        **Access functions:**

        QPointF **hotSpot** () const
        void **setHotSpot** (const QPointF &
        **value** )
        void **unsetHotSpot** ()
        """
        ...

    def state(self) -> QtCore.Qt.GestureState:
        """
        https://doc.qt.io/qt-6/qgesture.html#state-prop

        **[read-only] state : const Qt::GestureState**

        This property holds the current state of the gesture

        **Access functions:**

        Qt::GestureState **state** () const

        **Member Function Documentation**
        """
        ...

    def gestureType(self) -> QtCore.Qt.GestureType:
        """
        https://doc.qt.io/qt-6/qgesture.html#gestureType-prop

        **[read-only] gestureType : const Qt::GestureType**

        This property holds the type of the gesture

        **Access functions:**

        Qt::GestureType **gestureType** () const
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QMediaCaptureSession(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qmediacapturesession.html

    **Detailed Description**

    The QMediaCaptureSession is the central class that manages capturing of
    media on the local device.

    You can connect a camera and a microphone to QMediaCaptureSession using
    **setCamera** () and **setAudioInput** (). A preview of the captured media
    can be seen by setting a **QVideoSink**  of **QVideoWidget**  using
    **setVideoOutput** () and heard by routing the audio to an output device
    using **setAudioOutput** ().

    You can capture still images from a camera by setting a **QImageCapture**
    object on the capture session, and record audio/video using a
    **QMediaRecorder** .

    **See also** **QCamera** , **QAudioDevice** , **QMediaRecorder** ,
    **QImageCapture** , and **QMediaRecorder** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#QMediaCaptureSession

        **QMediaCaptureSession::QMediaCaptureSession(QObject * parent =
        nullptr)**

        Creates a session for media capture from the **parent** object.
        """
        ...

    def audioInputChanged(self) -> None:
        ...

    def audioOutput(self) -> QAudioOutput:
        ...

    def setAudioOutput(self, output: QAudioOutput) -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#setAudioOutput

        **void QMediaCaptureSession::setAudioOutput(QAudioOutput * output )**

        Sets the audio output device to **output**.

        **Note:** Setter function for property **audioOutput** .

        **See also** **audioOutput** ().
        """
        ...

    def videoSink(self) -> "QVideoSink":
        ...

    def setVideoSink(self, sink: "QVideoSink") -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#setVideoSink

        **void QMediaCaptureSession::setVideoSink(QVideoSink * sink )**

        Sets a **QVideoSink** , ( **sink** ), to a video preview for the capture
        session.

        A **QObject**  based preview is expected to have an invokable
        videoSink() method that returns a **QVideoSink** .

        The previously set preview is detached.
        """
        ...

    def videoOutput(self) -> QtCore.QObject:
        ...

    def setVideoOutput(self, output: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#setVideoOutput

        **void QMediaCaptureSession::setVideoOutput(QObject * output )**

        Sets a **QObject** , ( **output** ), to a video preview for the capture
        session.

        A **QObject**  based preview is expected to have an invokable
        videoSink() method that returns a **QVideoSink** .

        The previously set preview is detached.

        **Note:** Setter function for property **videoOutput** .

        **See also** **videoOutput** ().
        """
        ...

    def setRecorder(self, recorder: "QMediaRecorder") -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#recorder-prop

        **recorder : QMediaRecorder***

        This property holds the recorder object used to capture audio/video.

        Add a **QMediaRecorder**  object to the capture session to enable
        recording of audio and/or video from the capture session.

        **Access functions:**

        QMediaRecorder * **recorder** ()
        void **setRecorder** (QMediaRecorder
        * **recorder** )

        **Notifier signal:**

        void **recorderChanged** ()

        **Member Function Documentation**
        """
        ...

    def recorder(self) -> "QMediaRecorder":
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#recorder-prop

        **recorder : QMediaRecorder***

        This property holds the recorder object used to capture audio/video.

        Add a **QMediaRecorder**  object to the capture session to enable
        recording of audio and/or video from the capture session.

        **Access functions:**

        QMediaRecorder * **recorder** ()
        void **setRecorder** (QMediaRecorder
        * **recorder** )

        **Notifier signal:**

        void **recorderChanged** ()

        **Member Function Documentation**
        """
        ...

    def setImageCapture(self, imageCapture: QImageCapture) -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#imageCapture-prop

        **imageCapture : QImageCapture***

        This property holds the object used to capture still images.

        Add a **QImageCapture**  object to the capture session to enable
        capturing of still images from the camera.

        **Access functions:**

        QImageCapture * **imageCapture** ()
        void **setImageCapture**
        (QImageCapture * **imageCapture** )

        **Notifier signal:**

        void **imageCaptureChanged** ()
        """
        ...

    def imageCapture(self) -> QImageCapture:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#imageCapture-prop

        **imageCapture : QImageCapture***

        This property holds the object used to capture still images.

        Add a **QImageCapture**  object to the capture session to enable
        capturing of still images from the camera.

        **Access functions:**

        QImageCapture * **imageCapture** ()
        void **setImageCapture**
        (QImageCapture * **imageCapture** )

        **Notifier signal:**

        void **imageCaptureChanged** ()
        """
        ...

    def setCamera(self, camera: QCamera) -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#camera-prop

        **camera : QCamera***

        This property holds the camera used to capture video.

        Record video or take images by adding a camera to the capture session
        using this property,

        **Access functions:**

        QCamera * **camera** () const
        void **setCamera** (QCamera * **camera**
        )

        **Notifier signal:**

        void **cameraChanged** ()
        """
        ...

    def camera(self) -> QCamera:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#camera-prop

        **camera : QCamera***

        This property holds the camera used to capture video.

        Record video or take images by adding a camera to the capture session
        using this property,

        **Access functions:**

        QCamera * **camera** () const
        void **setCamera** (QCamera * **camera**
        )

        **Notifier signal:**

        void **cameraChanged** ()
        """
        ...

    def setAudioInput(self, device: QAudioInput) -> None:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#setAudioInput

        **void QMediaCaptureSession::setAudioInput(QAudioInput * input )**

        Sets the audio input device to **input**. If setting it to an empty
        **QAudioDevice**  the capture session will use the default input as
        defined by the operating system.

        **Note:** Setter function for property **audioInput** .

        **See also** **audioInput** ().
        """
        ...

    def audioInput(self) -> QAudioInput:
        """
        https://doc.qt.io/qt-6/qmediacapturesession.html#audioInput

        **QAudioInput *QMediaCaptureSession::audioInput() const**

        Returns the device that is being used to capture audio.

        **Note:** Getter function for property audioInput.

        **See also** **setAudioInput** ().
        """
        ...

    @property
    def audioOutputChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def cameraChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def imageCaptureChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def recorderChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def videoOutputChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...
